@@ -1,5 +1,10 @@
 #!/usr/bin/env bash
 
+if [ -z ${CI+x} ]; then
+  echo "this script is only intended to run in CI" >&2
+  exit 1
+fi
+
 set -e
 set -o pipefail
 set -u
@@ -7,7 +12,7 @@ set -x
 
 ci/test_coverage.py --init
 pushd build
-# Use GVBINDIR to specify where to generate and load config6
+# Use GVBINDIR to specify where to generate and load config8
 # since ctest sets LD_LIBRARY_PATH to point to all the
 # locations where the libs reside before cpack copies them to
 # the install directory. Without this Graphviz tries to use
@@ -17,9 +22,5 @@ cmd/dot/dot -v -c
 ctest --output-on-failure
 unset GVBINDIR
 popd
-# Many of the tests run by pytest currently trigger ASan
-# memory leak detections. Disable those for now.
-export ASAN_OPTIONS=detect_leaks=0
-export UBSAN_OPTIONS=print_stacktrace=1
 ci/test-job-script.sh
 ci/test_coverage.py --analyze
