@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -18,17 +18,10 @@
 #include "callbacks.h"
 #include <cgraph/cgraph.h>
 
-#define MAXIMUM_WIDGET_COUNT	97
-
     extern GladeXML *xml;	//global libglade vars
-    extern GtkWidget *gladewidget;
-
-    extern attribute attr[MAXIMUM_WIDGET_COUNT];
 
     void load_graph_properties(void);	//load from graph to gui
 
-    void load_attributes(void);	//loads attributes from a text file
-
 //GTK helper functions
 //void Color_Widget_bg (int r, int g, int b, GtkWidget *widget);        //change background color 
     void Color_Widget_bg(char *colorstring, GtkWidget * widget);
