@@ -3,12 +3,11 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <cgraph/alloc.h>
 #include "menucallbacks.h"
 #include "viewport.h"
 #include "tvnodes.h"
@@ -17,21 +16,21 @@
 #include "topviewsettings.h"
 #include "gltemplate.h"
 #include <common/const.h>
-#include <cgraph/agxbuf.h>
 #include <assert.h>
 #include <ctype.h>
+#include <glib.h>
+#include <stdlib.h>
 #include  "frmobjectui.h"
+#include <util/agxbuf.h>
 
-void mAttributesSlot(GtkWidget * widget, gpointer user_data)
-{
+void mAttributesSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
-    showAttrsWidget(view->Topview);
+    showAttrsWidget();
 }
 
-void mOpenSlot(GtkWidget * widget, gpointer user_data)
-{
+void mOpenSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -61,24 +60,21 @@ void mOpenSlot(GtkWidget * widget, gpointer user_data)
     gtk_widget_destroy(dialog);
 }
 
-void mSaveSlot(GtkWidget * widget, gpointer user_data)
-{
+void mSaveSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     save_graph();		//save without prompt
 }
 
-void mSaveAsSlot(GtkWidget * widget, gpointer user_data)
-{
+void mSaveAsSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     save_as_graph();		//save with prompt
 }
 
-void mCloseSlot(GtkWidget * widget, gpointer user_data)
-{
+void mCloseSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -86,14 +82,12 @@ void mCloseSlot(GtkWidget * widget, gpointer user_data)
 	close_graph(view);
 }
 
-void mOptionsSlot(GtkWidget * widget, gpointer user_data)
-{
+void mOptionsSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
 
-void mQuitSlot(GtkWidget * widget, gpointer user_data)
-{
+void mQuitSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -102,39 +96,33 @@ void mQuitSlot(GtkWidget * widget, gpointer user_data)
 }
 
 //edit
-void mCutSlot(GtkWidget * widget, gpointer user_data)
-{
+void mCutSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
 
-void mCopySlot(GtkWidget * widget, gpointer user_data)
-{
+void mCopySlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
 
-void mPasteSlot(GtkWidget * widget, gpointer user_data)
-{
+void mPasteSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
 
-void mDeleteSlot(GtkWidget * widget, gpointer user_data)
-{
+void mDeleteSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 }
-void mTopviewSettingsSlot(GtkWidget * widget, gpointer user_data)
-{
+void mTopviewSettingsSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
     show_settings_form();
 }
 
 //view
-void mShowToolBoxSlot(GtkWidget * widget, gpointer user_data)
-{
+void mShowToolBoxSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -144,8 +132,7 @@ void mShowToolBoxSlot(GtkWidget * widget, gpointer user_data)
 	printf("glwidget creation failed \n");
 }
 
-void mShowConsoleSlot(GtkWidget * widget, gpointer user_data)
-{
+void mShowConsoleSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -166,8 +153,7 @@ void mShowConsoleSlot(GtkWidget * widget, gpointer user_data)
 }
 
 //Graph
-void mNodeListSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNodeListSlot(GtkWidget *widget, void *user_data) {
 	(void)widget;
 	(void)user_data;
 
@@ -175,26 +161,22 @@ void mNodeListSlot(GtkWidget * widget, gpointer user_data)
 	setup_tree (view->g[view->activeGraph]);
 }
 
-void mNewNodeSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNewNodeSlot(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
 
-void mNewEdgeSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNewEdgeSlot(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
 
-void mNewClusterSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNewClusterSlot(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
 
-void mGraphPropertiesSlot(GtkWidget * widget, gpointer user_data)
-{
+void mGraphPropertiesSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -215,51 +197,44 @@ void mGraphPropertiesSlot(GtkWidget * widget, gpointer user_data)
     }
 }
 
-void mNodeFindSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNodeFindSlot(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
 
-static void mPropertiesSlot(gve_element element)
-{
+static void mPropertiesSlot(void) {
     if (view->activeGraph >= 0)
 	gtk_widget_hide(glade_xml_get_widget(xml, "frmObject"));
     gtk_widget_show(glade_xml_get_widget(xml, "frmObject"));
 }
 
-void mClusterPropertiesSlot(GtkWidget * widget, gpointer user_data)
-{
+void mClusterPropertiesSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
-    mPropertiesSlot(GVE_CLUSTER);
+    mPropertiesSlot();
 }
 
-void mNodePropertiesSlot(GtkWidget * widget, gpointer user_data)
-{
+void mNodePropertiesSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
-    mPropertiesSlot(GVE_NODE);
+    mPropertiesSlot();
 }
 
-void mEdgePropertiesSlot(GtkWidget * widget, gpointer user_data)
-{
+void mEdgePropertiesSlot(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
-    mPropertiesSlot(GVE_EDGE);
+    mPropertiesSlot();
 }
 
-void mShowCodeSlot(GtkWidget * widget, gpointer user_data)
-{
+void mShowCodeSlot(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
 
-void mAbout(GtkWidget * widget, gpointer user_data)
-{
+void mAbout(GtkWidget *widget, void *user_data) {
   (void)widget;
   (void)user_data;
 }
@@ -273,8 +248,7 @@ void change_cursor(GdkCursorType C)
     gdk_cursor_destroy(cursor);
 }
 
-void mTestgvpr(GtkWidget * widget, gpointer user_data)
-{
+void mTestgvpr(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
@@ -284,7 +258,6 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
     GtkTextIter endit;
     const char *args;
     int cloneGraph;
-    char **argv;
 
     args =
 	gtk_entry_get_text((GtkEntry *)
@@ -313,7 +286,8 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
 	argc++;
     } else
 	cloneGraph = 0;
-    argv = gv_calloc(argc + 1, sizeof(char*));
+    assert(argc <= 5);
+    char *argv[6] = {0};
     size_t j = 0;
     argv[j++] = "smyrna";
     if (cloneGraph)
@@ -337,7 +311,6 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
     assert(j == argc);
 
     run_gvpr(view->g[view->activeGraph], argc, argv);
-    free(argv);
     g_free(bf2);
 }
 
@@ -345,24 +318,21 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
    opens a file open dialog and load a gvpr program to gvpr script text box
    if the current script is modified, user should be informed about it
 */
-void on_gvprbuttonload_clicked(GtkWidget * widget, gpointer user_data)
-{
+void on_gvprbuttonload_clicked(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     FILE *input_file = NULL;
     char *str;
-    agxbuf xbuf;
+    agxbuf xbuf = {0};
     GtkTextBuffer *gtkbuf;	/*GTK buffer from glade GUI */
 
     char buf[BUFSIZ];
-    char xbuffer[BUFSIZ];
 
-    agxbinit(&xbuf, SMALLBUF, xbuffer);
-
-    /*file name should be returned in xbuf */
-    if (openfiledlg(0, NULL, &xbuf)) {
-	input_file = fopen(agxbuse(&xbuf), "r");
+    char *filename = NULL;
+    if (openfiledlg(&filename)) {
+	input_file = fopen(filename, "r");
+	g_free(filename);
 	if (input_file) {
 	    while (fgets(buf, BUFSIZ, input_file))
 		agxbput(&xbuf, buf);
@@ -385,24 +355,23 @@ void on_gvprbuttonload_clicked(GtkWidget * widget, gpointer user_data)
 }
 
 /*
-	opens a file open dialog and load a gvpr program to gvpr script text box
+	opens a file save dialog and save a gvpr program from gvpr script text box
 	if the current script is modified, user should be informed about it
 */
-void on_gvprbuttonsave_clicked(GtkWidget * widget, gpointer user_data)
-{
+void on_gvprbuttonsave_clicked(GtkWidget *widget, void *user_data) {
     (void)widget;
     (void)user_data;
 
     FILE *output_file = NULL;
-    agxbuf xbuf = {0};
     GtkTextBuffer *gtkbuf;	/*GTK buffer from glade GUI */
     char *bf2;
     GtkTextIter startit;
     GtkTextIter endit;
 
-    /*file name should be returned in xbuf */
-    if (savefiledlg(0, NULL, &xbuf)) {
-	output_file = fopen(agxbuse(&xbuf), "w");
+    char *filename = NULL;
+    if (savefiledlg(&filename)) {
+	output_file = fopen(filename, "w");
+	g_free(filename);
 	if (output_file) {
 	    gtkbuf =
 		gtk_text_view_get_buffer((GtkTextView *)
@@ -411,7 +380,8 @@ void on_gvprbuttonsave_clicked(GtkWidget * widget, gpointer user_data)
 	    gtk_text_buffer_get_start_iter(gtkbuf, &startit);
 	    gtk_text_buffer_get_end_iter(gtkbuf, &endit);
 	    bf2 = gtk_text_buffer_get_text(gtkbuf, &startit, &endit, 0);
-	    fprintf(output_file, "%s", bf2);
+	    fputs(bf2, output_file);
+	    free(bf2);
 	    fclose(output_file);
 	}
 
