@@ -3,12 +3,14 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "hotkeymap.h"
+#include <stdint.h>
+#include <util/alloc.h>
 
 static int get_mouse_mode(const char *s)
 {
@@ -112,27 +114,26 @@ static int get_drag(const char *s)
 
 void load_mouse_actions(ViewInfo * v)
 {
-    /*file parsing is temporarrily not available */
+    // file parsing is temporarily not available
     int i = 0;
     FILE *file;
-    char line[BUFSIZ];
+    char linebuf[BUFSIZ];
     char *a;
     char *action_file = smyrnaPath("mouse_actions.txt");
     file = fopen(action_file, "r");
     if (file != NULL) {
 	int ind = 0;
-	while (fgets(line, BUFSIZ, file) != NULL) {
+	while (fgets(linebuf, BUFSIZ, file) != NULL) {
 	    int idx = 0;
-	    a = strtok(line, ",");
+	    a = strtok(linebuf, ",");
 
-	    if ((line[0] == '#') || (line[0] == ' ')
-		|| (strlen(line) == 0))
+	    if (linebuf[0] == '#' || linebuf[0] == ' ' || strlen(linebuf) == 0)
 		continue;
 
+	    v->mouse_actions = gv_recalloc(v->mouse_actions, v->mouse_action_count,
+	                                   v->mouse_action_count + 1,
+	                                   sizeof(mouse_action_t));
 	    v->mouse_action_count++;
-	    v->mouse_actions =
-		realloc(v->mouse_actions,
-			v->mouse_action_count * sizeof(mouse_action_t));
 	    v->mouse_actions[ind].action = get_mouse_mode(a);
 	    v->mouse_actions[ind].index = i;
 
@@ -162,41 +163,28 @@ void load_mouse_actions(ViewInfo * v)
     free(action_file);
 }
 
-int get_key_action(ViewInfo * v, int key)
-{
-    int ind = 0;
-    for (; ind < v->mouse_action_count; ind++) {
-
-	if (v->mouse_actions[ind].hotkey == key)
-	    return v->mouse_actions[ind].action;
-    }
-    return -1;
-}
-
-
 int get_mode(ViewInfo * v)
 {
-    int ind = 0;
     glMouseButtonType curMouseType = v->mouse.t;
-    int curDragging = ((v->mouse.dragX != 0) || (v->mouse.dragY != 0));
+    int curDragging = v->mouse.dragX != 0 || v->mouse.dragY != 0;
     smyrna_view_mode view_mode;
     view_mode = smyrna_2D;
-    if (v->active_camera >= 0)
+    if (v->active_camera != SIZE_MAX)
 	view_mode = smyrna_3D;
     if (v->Topview->fisheyeParams.active)
 	view_mode = smyrna_fisheye;
 
 
-    for (; ind < v->mouse_action_count; ind++) {
+    for (size_t ind = 0; ind < v->mouse_action_count; ind++) {
 
-	if ((v->mouse_actions[ind].hotkey == v->keymap.keyVal)
-	    && (v->mouse_actions[ind].type == curMouseType)
-	    && (v->mouse_actions[ind].drag == curDragging)
+	if (v->mouse_actions[ind].hotkey == v->keyVal
+	    && v->mouse_actions[ind].type == curMouseType
+	    && v->mouse_actions[ind].drag == curDragging
 	    &&
-	    ((v->mouse_actions[ind].mode == view_mode)
-	     || (v->mouse_actions[ind].mode == smyrna_all)
-	     || ((v->mouse_actions[ind].mode == smyrna_all_but_fisheye)
-		 && (view_mode != smyrna_fisheye))
+	    (v->mouse_actions[ind].mode == view_mode
+	     || v->mouse_actions[ind].mode == smyrna_all
+	     || (v->mouse_actions[ind].mode == smyrna_all_but_fisheye
+		 && view_mode != smyrna_fisheye)
 	    )) {
 	    return v->mouse_actions[ind].action;
 
