@@ -15,13 +15,13 @@
 #include <windows.h>
 #include <windowsx.h>
 #endif
-#include "frmobjectui.h"
 #include "glexpose.h"
 #include "gltemplate.h"
 #include "glutrender.h"
-#include "gui.h"
+#include "gui/frmobjectui.h"
+#include "gui/gui.h"
+#include "gui/menucallbacks.h"
 #include "gvprpipe.h"
-#include "menucallbacks.h"
 #include "viewport.h"
 #include <assert.h>
 #include <glade/glade.h>
@@ -34,6 +34,7 @@
 #include <util/alloc.h>
 #include <util/exit.h>
 #include <util/gv_find_me.h>
+#include <util/path.h>
 
 static char *smyrnaDir; ///< path to directory containing smyrna data files
 static char *smyrnaGlade;
@@ -163,12 +164,6 @@ static void windowedMode(int argc, char *argv[]) {
 /// find an absolute path to where Smyrna auxiliary files are stored
 static char *find_share(void) {
 
-#ifdef _WIN32
-  const char PATH_SEPARATOR = '\\';
-#else
-  const char PATH_SEPARATOR = '/';
-#endif
-
   // find the path to the `smyrna` binary
   char *smyrna_exe = gv_find_me();
   if (smyrna_exe == NULL) {
