@@ -3,29 +3,26 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef BLOCKPATH_H
-#define BLOCKPATH_H
-
 #include <circogen/circular.h>
+#include <circogen/nodelist.h>
 
-    extern nodelist_t *layout_block(Agraph_t * g, block_t * sn, double);
-    extern int cmpNodeDegree(Dt_t *, Agnode_t **, Agnode_t **, Dtdisc_t *);
+nodelist_t layout_block(Agraph_t *g, block_t *sn, double, circ_state *state);
 
 #ifdef DEBUG
     extern void prTree(Agraph_t * g);
 #endif
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
