@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -17,7 +17,8 @@ typedef struct {
     blocklist_t bl;
     int orderCount;
     int blockCount;
-    attrsym_t *N_artpos;
+    int graphCopyCount; ///< how many cloned graphs have we created?
+    int spanningTreeCount; ///< how many spanning trees have we created?
     attrsym_t *N_root;
     char *rootname;
     double min_dist;
@@ -68,14 +69,12 @@ typedef struct {
 
 typedef struct {
     int order;
-    Agedge_t* next;
 } edata;
 
 #define NDATA(n) ((ndata*)(ND_alg(n)))
 #define DNODE(n)	(NDATA(n)->dnode)
 
 #define EDGEDATA(e)  ((edata*)(ED_alg(e)))
-#define ENEXT(e)     (EDGEDATA(e)->next)
 #define EDGEORDER(e) (EDGEDATA(e)->order)
 
 #define DATA(n) ((cdata*)(ND_alg(n)))
@@ -130,7 +129,7 @@ extern "C" {
     extern void prData(Agnode_t * n, int pass);
 #endif
 
-    extern void circularLayout(Agraph_t * sg, Agraph_t* rg);
+void circularLayout(Agraph_t *sg, Agraph_t *rg, int *blockCount);
 
 #ifdef __cplusplus
 }
