@@ -8,12 +8,11 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include    <cgraph/alloc.h>
 #include    <circogen/circular.h>
 #include    <neatogen/adjust.h>
 #include    <pack/pack.h>
@@ -21,6 +20,7 @@
 #include    <stddef.h>
 #include    <stdbool.h>
 #include    <string.h>
+#include    <util/alloc.h>
 
 static void circular_init_edge(edge_t * e)
 {
@@ -60,8 +60,7 @@ void circo_init_graph(graph_t * g)
     circular_init_node_edge(g);
 }
 
-/* makeDerivedNode:
- * Make a node in the derived graph, with the given name.
+/* Make a node in the derived graph, with the given name.
  * orig points to what it represents, either a real node or
  * a cluster. Copy size info from original node; needed for
  * adjustNodes and packSubgraphs.
@@ -83,23 +82,19 @@ static node_t *makeDerivedNode(graph_t * dg, char *name, int isNode,
     return n;
 }
 
-/* circomps:
- * Construct a strict, undirected graph with no loops from g.
+/* Construct a strict, undirected graph with no loops from g.
  * Construct the connected components with the provision that all
  * nodes in a block subgraph are considered connected.
  * Return array of components with number of components in cnt.
  * Each component has its blocks as subgraphs.
  * FIX: Check that blocks are disjoint.
  */
-static Agraph_t **circomps(Agraph_t * g, int *cnt)
-{
-    int c_cnt;
+static Agraph_t **circomps(Agraph_t *g, size_t *cnt) {
     Agraph_t **ccs;
     Agraph_t *dg;
     Agnode_t *n, *v, *dt, *dh;
     Agedge_t *e;
     Agraph_t *sg;
-    int i;
     Agedge_t *ep;
     Agnode_t *p;
 
@@ -124,10 +119,11 @@ static Agraph_t **circomps(Agraph_t * g, int *cnt)
 	}
     }
 
+    size_t c_cnt;
     ccs = ccomps(dg, &c_cnt, 0);
 
     /* replace block nodes with block contents */
-    for (i = 0; i < c_cnt; i++) {
+    for (size_t i = 0; i < c_cnt; i++) {
 	sg = ccs[i];
 
 	/* add edges: since sg is a union of components, all edges
@@ -150,7 +146,7 @@ static Agraph_t **circomps(Agraph_t * g, int *cnt)
     /* Finally, add edge data to edges */
     for (n = agfstnode(dg); n; n = agnxtnode(dg, n)) {
 	for (e = agfstout(dg, n); e; e = agnxtout(dg, e)) {
-	    ED_alg(e) = NEW(edata);
+	    ED_alg(e) = gv_alloc(sizeof(edata));
 	}
     }
 
@@ -158,8 +154,6 @@ static Agraph_t **circomps(Agraph_t * g, int *cnt)
     return ccs;
 }
 
-/* closeDerivedGraph:
- */
 static void closeDerivedGraph(graph_t * g)
 {
     node_t *n;
@@ -175,8 +169,7 @@ static void closeDerivedGraph(graph_t * g)
     agclose(g);
 }
 
-/* copyPosns:
- * Copy position of nodes in given subgraph of derived graph
+/* Copy position of nodes in given subgraph of derived graph
  * to corresponding node in original graph.
  * FIX: consider assigning from n directly to ORIG(n).
  */
@@ -192,20 +185,18 @@ static void copyPosns(graph_t * g)
     }
 }
 
-/* circoLayout:
- */
 void circoLayout(Agraph_t * g)
 {
     Agraph_t **ccs;
     Agraph_t *sg;
-    int ncc;
-    int i;
 
     if (agnnodes(g)) {
+	size_t ncc;
 	ccs = circomps(g, &ncc);
 
+	int blockCount = 0;
 	if (ncc == 1) {
-	    circularLayout(ccs[0], g);
+	    circularLayout(ccs[0], g, &blockCount);
 	    copyPosns(ccs[0]);
 	    adjustNodes(g);
 	} else {
@@ -213,9 +204,9 @@ void circoLayout(Agraph_t * g)
 	    pack_info pinfo;
 	    getPackInfo(g, l_node, CL_OFFSET, &pinfo);
 
-	    for (i = 0; i < ncc; i++) {
+	    for (size_t i = 0; i < ncc; i++) {
 		sg = ccs[i];
-		circularLayout(sg, g);
+		circularLayout(sg, g, &blockCount);
 		adjustNodes(sg);
 	    }
 	    /* FIX: splines have not been calculated for dg
@@ -223,15 +214,13 @@ void circoLayout(Agraph_t * g)
 	     * construct components of g from ccs and use that in packing.
 	     */
 	    packSubgraphs(ncc, ccs, dg, &pinfo);
-	    for (i = 0; i < ncc; i++)
+	    for (size_t i = 0; i < ncc; i++)
 		copyPosns(ccs[i]);
 	}
 	free(ccs);
     }
 }
 
-/* circo_layout:
- */
 void circo_layout(Agraph_t * g)
 {
     if (agnnodes(g) == 0) return;
@@ -243,9 +232,7 @@ void circo_layout(Agraph_t * g)
     dotneato_postprocess(g);
 }
 
-/* circo_cleanup:
- * ND_alg is freed in circo_layout
- */
+/// ND_alg is freed in circo_layout
 void circo_cleanup(graph_t * g)
 {
     node_t *n;
@@ -255,7 +242,7 @@ void circo_cleanup(graph_t * g)
     if (n == NULL)
 	return;			/* g is empty */
 
-    closeDerivedGraph((graph_t*)GD_alg(g));	/* delete derived graph */
+    closeDerivedGraph(GD_alg(g)); // delete derived graph
 
     /* free (ND_alg(n)); */
     for (; n; n = agnxtnode(g, n)) {
