@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -14,35 +14,36 @@
  */
 
 #include	<dotgen/dot.h>
+#include	<stdbool.h>
 
 #define		UP		0
 #define		DOWN	1
 
-static boolean samedir(edge_t * e, edge_t * f)
+static bool samedir(edge_t * e, edge_t * f)
 {
     edge_t *e0, *f0;
 
     for (e0 = e; e0 != NULL && ED_edge_type(e0) != NORMAL; e0 = ED_to_orig(e0));
     if (e0 == NULL)
-	return FALSE;
+	return false;
     for (f0 = f; f0 != NULL && ED_edge_type(f0) != NORMAL; f0 = ED_to_orig(f0));
     if (f0 == NULL)
-	return FALSE;
+	return false;
     if (ED_conc_opp_flag(e0))
-	return FALSE;
+	return false;
     if (ED_conc_opp_flag(f0))
-	return FALSE;
+	return false;
     return ((ND_rank(agtail(f0)) - ND_rank(aghead(f0)))
 	    * (ND_rank(agtail(e0)) - ND_rank(aghead(e0))) > 0);
 }
 
-static boolean downcandidate(node_t * v)
+static bool downcandidate(node_t * v)
 {
     return ND_node_type(v) == VIRTUAL && ND_in(v).size == 1
 	    && ND_out(v).size == 1 && ND_label(v) == NULL;
 }
 
-static boolean bothdowncandidates(node_t * u, node_t * v)
+static bool bothdowncandidates(node_t * u, node_t * v)
 {
     edge_t *e, *f;
     e = ND_in(u).list[0];
@@ -51,16 +52,16 @@ static boolean bothdowncandidates(node_t * u, node_t * v)
 	return samedir(e, f)
 	    && portcmp(ED_tail_port(e), ED_tail_port(f)) == 0;
     }
-    return FALSE;
+    return false;
 }
 
-static boolean upcandidate(node_t * v)
+static bool upcandidate(node_t * v)
 {
     return ND_node_type(v) == VIRTUAL && ND_out(v).size == 1
 	    && ND_in(v).size == 1 && ND_label(v) == NULL;
 }
 
-static boolean bothupcandidates(node_t * u, node_t * v)
+static bool bothupcandidates(node_t * u, node_t * v)
 {
     edge_t *e, *f;
     e = ND_out(u).list[0];
@@ -69,19 +70,19 @@ static boolean bothupcandidates(node_t * u, node_t * v)
 	return samedir(e, f)
 	    && portcmp(ED_head_port(e), ED_head_port(f)) == 0;
     }
-    return FALSE;
+    return false;
 }
 
 static void mergevirtual(graph_t * g, int r, int lpos, int rpos, int dir)
 {
-    int i, k;
-    node_t *left, *right;
+    int k;
+    node_t *left;
     edge_t *e, *f, *e0;
 
     left = GD_rank(g)[r].v[lpos];
     /* merge all right nodes into the leftmost one */
-    for (i = lpos + 1; i <= rpos; i++) {
-	right = GD_rank(g)[r].v[i];
+    for (int i = lpos + 1; i <= rpos; i++) {
+	node_t *const right = GD_rank(g)[r].v[i];
 	if (dir == DOWN) {
 	    while ((e = ND_out(right).list[0])) {
 		for (k = 0; (f = ND_out(left).list[k]); k++)
@@ -91,7 +92,6 @@ static void mergevirtual(graph_t * g, int r, int lpos, int rpos, int dir)
 		    f = virtual_edge(left, aghead(e), e);
 		while ((e0 = ND_in(right).list[0])) {
 		    merge_oneway(e0, f);
-		    /*ED_weight(f) += ED_weight(e0); */
 		    delete_fast_edge(e0);
 		}
 		delete_fast_edge(e);
@@ -114,13 +114,10 @@ static void mergevirtual(graph_t * g, int r, int lpos, int rpos, int dir)
 	delete_fast_node(g, right);
     }
     k = lpos + 1;
-    i = rpos + 1;
-    while (i < GD_rank(g)[r].n) {
-	node_t *n;
-	n = GD_rank(g)[r].v[k] = GD_rank(g)[r].v[i];
+    for (int i = rpos + 1; i < GD_rank(g)[r].n; ++i) {
+	node_t *const n = GD_rank(g)[r].v[k] = GD_rank(g)[r].v[i];
 	ND_order(n) = k;
 	k++;
-	i++;
     }
     GD_rank(g)[r].n = k;
     GD_rank(g)[r].v[k] = NULL;
@@ -158,16 +155,15 @@ static int rebuild_vlists(graph_t * g)
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	lead = GD_rankleader(g)[r];
 	if (lead == NULL) {
-		agerr(AGERR, "rebuild_vlists: lead is null for rank %d\n", r);
+		agerrorf("rebuild_vlists: lead is null for rank %d\n", r);
 		return -1;
 	}
 	else if (GD_rank(dot_root(g))[r].v[ND_order(lead)] != lead) {
-	    agerr(AGERR, "rebuild_vlists: rank lead %s not in order %d of rank %d\n", 
+	    agerrorf("rebuild_vlists: rank lead %s not in order %d of rank %d\n", 
 		agnameof(lead), ND_order(lead), r);
 	    return -1;
 	}
-	GD_rank(g)[r].v =
-	    GD_rank(dot_root(g))[r].v + ND_order((GD_rankleader(g)[r]));
+	GD_rank(g)[r].v = GD_rank(dot_root(g))[r].v + ND_order(GD_rankleader(g)[r]);
 	maxi = -1;
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
 	    if ((n = GD_rank(g)[r].v[i]) == NULL)
@@ -187,7 +183,7 @@ static int rebuild_vlists(graph_t * g)
 	    }
 	}
 	if (maxi == -1)
-	    agerr(AGWARN, "degenerate concentrated rank %s,%d\n", agnameof(g),
+	    agwarningf("degenerate concentrated rank %s,%d\n", agnameof(g),
 		  r);
 	GD_rank(g)[r].n = maxi + 1;
     }
