@@ -3,16 +3,25 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include <assert.h>
+#include <limits.h>
 #include <time.h>
 #include <dotgen/dot.h>
 #include <pack/pack.h>
 #include <dotgen/aspect.h>
+#include <stdbool.h>
+#include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <util/alloc.h>
+#include <util/debug.h>
+#include <util/itos.h>
+#include <util/streq.h>
 
 static void
 dot_init_subg(graph_t * g, graph_t* droot)
@@ -20,7 +29,7 @@ dot_init_subg(graph_t * g, graph_t* droot)
     graph_t* subg;
 
     if ((g != agroot(g)))
-	agbindrec(g, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+	agbindrec(g, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     if (g == droot)
 	GD_dotroot(agroot(g)) = droot;
 	
@@ -33,7 +42,7 @@ dot_init_subg(graph_t * g, graph_t* droot)
 static void 
 dot_init_node(node_t * n)
 {
-    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);	//graph custom data
+    agbindrec(n, "Agnodeinfo_t", sizeof(Agnodeinfo_t), true);	//graph custom data
     common_init_node(n);
     gv_nodesize(n, GD_flip(agraphof(n)));
     alloc_elist(4, ND_in(n));
@@ -48,7 +57,7 @@ static void
 dot_init_edge(edge_t * e)
 {
     char *tailgroup, *headgroup;
-    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), TRUE);	//graph custom data
+    agbindrec(e, "Agedgeinfo_t", sizeof(Agedgeinfo_t), true);	//graph custom data
     common_init_edge(e);
 
     ED_weight(e) = late_int(e, E_weight, 1, 0);
@@ -64,7 +73,13 @@ dot_init_edge(edge_t * e)
 	ED_weight(e) = 0;
     }
 
-    ED_showboxes(e) = late_int(e, E_showboxes, 0, 0);
+    {
+	int showboxes = late_int(e, E_showboxes, 0, 0);
+	if (showboxes > UCHAR_MAX) {
+	    showboxes = UCHAR_MAX;
+	}
+	ED_showboxes(e) = (unsigned char)showboxes;
+    }
     ED_minlen(e) = late_int(e, E_minlen, 1, 0);
 }
 
@@ -100,15 +115,14 @@ dot_cleanup_node(node_t * n)
 static void free_virtual_edge_list(node_t * n)
 {
     edge_t *e;
-    int i;
 
-    for (i = ND_in(n).size - 1; i >= 0; i--) {
+    for (size_t i = ND_in(n).size - 1; i != SIZE_MAX; i--) {
 	e = ND_in(n).list[i];
 	delete_fast_edge(e);
 	free(e->base.data);
 	free(e);
     }
-    for (i = ND_out(n).size - 1; i >= 0; i--) {
+    for (size_t i = ND_out(n).size - 1; i != SIZE_MAX; i--) {
 	e = ND_out(n).list[i];
 	delete_fast_edge(e);
 	free(e->base.data);
@@ -141,7 +155,9 @@ dot_cleanup_graph(graph_t * g)
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
 	dot_cleanup_graph(subg);
     }
-    if (! agbindrec(g, "Agraphinfo_t", 0, TRUE)) return;
+    if (! agbindrec(g, "Agraphinfo_t", 0, true)) return;
+    free(GD_drawing(g));
+    GD_drawing(g) = NULL;
     free (GD_clust(g));
     free (GD_rankleader(g));
 
@@ -156,7 +172,6 @@ dot_cleanup_graph(graph_t * g)
     }
     if (g != agroot(g)) {
 	free_label (GD_label(g));
-	agdelrec(g,"Agraphinfo_t");
     }
 }
 
@@ -256,8 +271,7 @@ removeFill (Agraph_t * g)
 
 }
 
-#define ag_xset(x,a,v) agxset(x,a,v)
-#define agnodeattr(g,n,v) agattr(g,AGNODE,n,v)
+#define agnodeattr(g,n,v) agattr_text(g,AGNODE,n,v)
 
 static void
 attach_phase_attrs (Agraph_t * g, int maxphase)
@@ -265,68 +279,65 @@ attach_phase_attrs (Agraph_t * g, int maxphase)
     Agsym_t* rk = agnodeattr(g,"rank","");
     Agsym_t* order = agnodeattr(g,"order","");
     Agnode_t* n;
-    char buf[BUFSIZ];
 
     for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
 	if (maxphase >= 1) {
-	    snprintf(buf, sizeof(buf), "%d", ND_rank(n));
-	    ag_xset(n,rk,buf);
+	    agxset(n, rk, ITOS(ND_rank(n)));
 	}
 	if (maxphase >= 2) {
-	    snprintf(buf, sizeof(buf), "%d", ND_order(n));
-	    ag_xset(n,order,buf);
+	    agxset(n, order, ITOS(ND_order(n)));
 	}
     }
 }
 
-static void dotLayout(Agraph_t * g)
-{
-    aspect_t aspect;
-    aspect_t* asp;
+/// @return 0 on success
+static int dotLayout(Agraph_t *g) {
     int maxphase = late_int(g, agfindgraphattr(g,"phase"), -1, 1);
 
-    setEdgeType (g, ET_SPLINE);
-    asp = setAspect (g, &aspect);
+    setEdgeType (g, EDGETYPE_SPLINE);
+    setAspect(g);
 
     dot_init_subg(g,g);
     dot_init_node_edge(g);
 
-    do {
-        dot_rank(g, asp);
-	if (maxphase == 1) {
-	    attach_phase_attrs (g, 1);
-	    return;
-	}
-	if (aspect.badGraph) {
-	    agerr(AGWARN, "dot does not support the aspect attribute for disconnected graphs or graphs with clusters\n");
-	    asp = NULL;
-	    aspect.nextIter = 0;
-	}
-        dot_mincross(g, (asp != NULL));
-	if (maxphase == 2) {
-	    attach_phase_attrs (g, 2);
-	    return;
-	}
-        dot_position(g, asp);
-	if (maxphase == 3) {
-	    attach_phase_attrs (g, 2);  /* positions will be attached on output */
-	    return;
-	}
-	aspect.nPasses--;
-    } while (aspect.nextIter && aspect.nPasses);
+    GV_INFO("Starting phase 1 [dot_rank]");
+    dot_rank(g);
+    if (maxphase == 1) {
+        attach_phase_attrs (g, 1);
+        return 0;
+    }
+    GV_INFO("Starting phase 2 [dot_mincross]");
+    const int rc = dot_mincross(g);
+    if (rc != 0) {
+        return rc;
+    }
+    if (maxphase == 2) {
+        attach_phase_attrs (g, 2);
+        return 0;
+    }
+    GV_INFO("Starting phase 3 [dot_position]");
+    dot_position(g);
+    if (maxphase == 3) {
+        attach_phase_attrs (g, 2);  /* positions will be attached on output */
+        return 0;
+    }
     if (GD_flags(g) & NEW_RANK)
 	removeFill (g);
     dot_sameports(g);
-    dot_splines(g);
+    const int r = dot_splines(g);
+    if (r != 0) {
+	return r;
+    }
     if (mapbool(agget(g, "compound")))
 	dot_compoundEdges(g);
+    return 0;
 }
 
 static void
 initSubg (Agraph_t* sg, Agraph_t* g)
 {
-    agbindrec(sg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
-    GD_drawing(sg) = NEW(layout_t);
+    agbindrec(sg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
+    GD_drawing(sg) = gv_alloc(sizeof(layout_t));
     GD_drawing(sg)->quantum = GD_drawing(g)->quantum; 
     GD_drawing(sg)->dpi = GD_drawing(g)->dpi;
     GD_gvc(sg) = GD_gvc (g);
@@ -337,58 +348,47 @@ initSubg (Agraph_t* sg, Agraph_t* g)
     GD_fontnames(sg) = GD_fontnames(g);
 }
 
-/* attachPos:
- * the packing library assumes all units are in inches stored in ND_pos, so we
+/* the packing library assumes all units are in inches stored in ND_pos, so we
  * have to copy the position info there.
  */
 static void
 attachPos (Agraph_t* g)
 {
     node_t* np;
-    double* ps = N_NEW(2*agnnodes(g), double);
 
     for (np = agfstnode(g); np; np = agnxtnode(g, np)) {
-	ND_pos(np) = ps;
-	ps[0] = PS2INCH(ND_coord(np).x);
-	ps[1] = PS2INCH(ND_coord(np).y);
-	ps += 2;
+	ND_pos(np) = gv_calloc(2, sizeof(double));
+	ND_pos(np)[0] = PS2INCH(ND_coord(np).x);
+	ND_pos(np)[1] = PS2INCH(ND_coord(np).y);
     }
 }
 
-/* resetCoord:
- * Store new position info from pack library call, stored in ND_pos in inches,
+/* Store new position info from pack library call, stored in ND_pos in inches,
  * back to ND_coord in points.
  */
 static void
 resetCoord (Agraph_t* g)
 {
-    node_t* np = agfstnode(g);
-    double* sp = ND_pos(np);
-    double* ps = sp;
-
-    for (np = agfstnode(g); np; np = agnxtnode(g, np)) {
-	ND_pos(np) = 0;
-	ND_coord(np).x = INCH2PS(ps[0]);
-	ND_coord(np).y = INCH2PS(ps[1]);
-	ps += 2;
+    for (node_t *np = agfstnode(g); np; np = agnxtnode(g, np)) {
+	ND_coord(np).x = INCH2PS(ND_pos(np)[0]);
+	ND_coord(np).y = INCH2PS(ND_pos(np)[1]);
+	free(ND_pos(np));
+	ND_pos(np) = NULL;
     }
-    free (sp);
 }
 
-/* copyCluster:
- */
 static void
 copyCluster (Agraph_t* scl, Agraph_t* cl)
 {
     int nclust, j;
     Agraph_t* cg;
 
-    agbindrec(cl, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+    agbindrec(cl, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
     GD_bb(cl) = GD_bb(scl);
     GD_label_pos(cl) = GD_label_pos(scl);
     memcpy(GD_border(cl), GD_border(scl), 4*sizeof(pointf));
     nclust = GD_n_cluster(cl) = GD_n_cluster(scl);
-    GD_clust(cl) = N_NEW(nclust+1,Agraph_t*);
+    GD_clust(cl) = gv_calloc(nclust + 1, sizeof(Agraph_t*));
     for (j = 1; j <= nclust; j++) {
 	cg = mapClust(GD_clust(scl)[j]);
 	GD_clust(cl)[j] = cg;
@@ -399,24 +399,21 @@ copyCluster (Agraph_t* scl, Agraph_t* cl)
     GD_label(scl) = NULL;
 }
 
-/* copyClusterInfo:
- * Copy cluster tree and info from components to main graph.
+/* Copy cluster tree and info from components to main graph.
  * Note that the original clusters have no Agraphinfo_t at this time.
  */
-static void
-copyClusterInfo (int ncc, Agraph_t** ccs, Agraph_t* root)
-{
-    int j, i, nclust = 0;
+static void copyClusterInfo(size_t ncc, Agraph_t **ccs, Agraph_t *root) {
+    int j, nclust = 0;
     Agraph_t* sg;
     Agraph_t* cg;
 
-    for (i = 0; i < ncc; i++) 
+    for (size_t i = 0; i < ncc; i++)
 	nclust += GD_n_cluster(ccs[i]);
 
     GD_n_cluster(root) = nclust;
-    GD_clust(root) = N_NEW(nclust+1,Agraph_t*);
+    GD_clust(root) = gv_calloc(nclust + 1, sizeof(Agraph_t*));
     nclust = 1;
-    for (i = 0; i < ncc; i++) {
+    for (size_t i = 0; i < ncc; i++) {
 	sg = ccs[i];
 	for (j = 1; j <= GD_n_cluster(sg); j++) {
 	    cg = mapClust(GD_clust(sg)[j]);
@@ -426,15 +423,13 @@ copyClusterInfo (int ncc, Agraph_t** ccs, Agraph_t* root)
     } 
 }
 
-/* doDot:
- * Assume g has nodes.
+/* Assume g has nodes.
+ *
+ * @return 0 on success
  */
-static void doDot (Agraph_t* g)
-{
+static int doDot(Agraph_t *g) {
     Agraph_t **ccs;
     Agraph_t *sg;
-    int ncc;
-    int i;
     pack_info pinfo;
     int Pack = getPack(g, -1, CL_OFFSET);
     pack_mode mode = getPackModeInfo (g, l_undef, &pinfo);
@@ -444,27 +439,40 @@ static void doDot (Agraph_t* g)
 	/* No pack information; use old dot with components
          * handled during layout
          */
-	dotLayout(g);
+	const int rc = dotLayout(g);
+	if (rc != 0) {
+	    return rc;
+	}
     } else {
 	/* fill in default values */
 	if (mode == l_undef) 
 	    pinfo.mode = l_graph;
 	else if (Pack < 0)
 	    Pack = CL_OFFSET;
-	pinfo.margin = Pack;
-	pinfo.fixed = 0;
+	assert(Pack >= 0);
+	pinfo.margin = (unsigned)Pack;
+	pinfo.fixed = NULL;
 
           /* components using clusters */
+	size_t ncc;
 	ccs = cccomps(g, &ncc, 0);
 	if (ncc == 1) {
-	    dotLayout(g);
+	    const int rc = dotLayout(g);
+	    if (rc != 0) {
+		free(ccs);
+		return rc;
+	    }
 	} else if (GD_drawing(g)->ratio_kind == R_NONE) {
-	    pinfo.doSplines = 1;
+	    pinfo.doSplines = true;
 
-	    for (i = 0; i < ncc; i++) {
+	    for (size_t i = 0; i < ncc; i++) {
 		sg = ccs[i];
 		initSubg (sg, g);
-		dotLayout (sg);
+		const int rc = dotLayout (sg);
+		if (rc != 0) {
+		    free(ccs);
+		    return rc;
+		}
 	    }
 	    attachPos (g);
 	    packSubgraphs(ncc, ccs, g, &pinfo);
@@ -476,21 +484,29 @@ static void doDot (Agraph_t* g)
              * One possibility is to layout nodes, pack, then apply the ratio
              * adjustment. We would then have to re-adjust all positions.
              */
-	    dotLayout(g);
+	    const int rc = dotLayout(g);
+	    if (rc != 0) {
+		free(ccs);
+		return rc;
+	    }
 	}
 
-	for (i = 0; i < ncc; i++) {
-	    free (GD_drawing(ccs[i]));
+	for (size_t i = 0; i < ncc; i++) {
 	    dot_cleanup_graph(ccs[i]);
 	    agdelete(g, ccs[i]);
 	}
 	free(ccs);
     }
+    return 0;
 }
 
 void dot_layout(Agraph_t * g)
 {
-    if (agnnodes(g)) doDot (g);
+    if (agnnodes(g)) {
+	if (doDot(g) != 0) { // error?
+	    return;
+	}
+    }
     dotneato_postprocess(g);
 }
 
@@ -499,3 +515,14 @@ Agraph_t * dot_root (void* p)
     return GD_dotroot(agroot(p));
 }
 
+/**
+ * @defgroup engines Graphviz layout engines
+ * @{
+ * @dir lib/dotgen
+ * @brief [hierarchical or layered](https://en.wikipedia.org/wiki/Layered_graph_drawing) layout engine, API dotgen/dotprocs.h
+ *
+ * [Dot layout user manual](https://graphviz.org/docs/layouts/dot/)
+ *
+ * Other @ref engines
+ * @}
+ */
