@@ -377,23 +377,18 @@ fixLabelOrder (graph_t* g, rank_t* rk)
 void
 checkLabelOrder (graph_t* g)
 {
-    int j, r, lo, hi;
     graph_t* lg = NULL;
-    rank_t* rk;
-    Agnode_t* u;
-    Agnode_t* n;
-    Agedge_t* e;
 
-    for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
-	rk = GD_rank(g)+r;
-	for (j = 0; j < rk->n; j++) {
-	    u = rk->v[j];
-	    if ((e = ND_alg(u))) {
+    for (int r = GD_minrank(g); r <= GD_maxrank(g); r++) {
+	rank_t *const rk = GD_rank(g)+r;
+	for (int j = 0; j < rk->n; j++) {
+	    Agnode_t *const u = rk->v[j];
+	    if (ND_alg(u)) {
 		if (!lg) lg = agopen ("lg", Agstrictdirected, 0);
-		n = agnode(lg, ITOS(j), 1);
+		Agnode_t *const n = agnode(lg, ITOS(j), 1);
 		agbindrec(n, "info", sizeof(info_t), true);
-		lo = ND_order(aghead(ND_out(u).list[0]));
-		hi = ND_order(aghead(ND_out(u).list[1]));
+		int lo = ND_order(aghead(ND_out(u).list[0]));
+		int hi = ND_order(aghead(ND_out(u).list[1]));
 		if (lo > hi) {
 		    SWAP(&lo, &hi);
 		}
@@ -512,7 +507,7 @@ static int betweenclust(edge_t * e)
 {
     while (ED_to_orig(e))
 	e = ED_to_orig(e);
-    return (ND_clust(agtail(e)) != ND_clust(aghead(e)));
+    return ND_clust(agtail(e)) != ND_clust(aghead(e));
 }
 
 static void do_ordering_node(graph_t *g, node_t *n, bool outflag) {
@@ -534,8 +529,7 @@ static void do_ordering_node(graph_t *g, node_t *n, bool outflag) {
     }
     if (ne <= 1)
 	return;
-    /* write null terminator at end of list.
-       requires +1 in TE_list alloccation */
+    // Write null terminator at end of list. Requires +1 in TE_list allocation.
     sortlist[ne] = 0;
     qsort(sortlist, ne, sizeof(sortlist[0]), edgeidcmpf);
     for (ne = 1; (f = sortlist[ne]); ne++) {
@@ -695,7 +689,7 @@ static int out_cross(node_t * v, node_t * w)
 
 	for (e1 = ND_out(v).list; *e1; e1++) {
 	    t = ND_order(aghead(*e1)) - inv;
-	    if (t > 0 || (t == 0 && (ED_head_port(*e1)).p.x > (ED_head_port(*e2)).p.x))
+	    if (t > 0 || (t == 0 && ED_head_port(*e1).p.x > ED_head_port(*e2).p.x))
 		cross += ED_xpenalty(*e1) * cnt;
 	}
     }
