@@ -3,10 +3,11 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
+
 #include <sparse/general.h>
 #include <sparse/SparseMatrix.h>
 #include <sparse/QuadTree.h>
@@ -16,6 +17,9 @@
 #include <sparse/color_palette.h>
 #include <stdbool.h>
 #include <string.h>
+#include <util/alloc.h>
+#include <util/debug.h>
+#include <util/random.h>
 
 static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
                                              bool weightedQ, SparseMatrix A,
@@ -29,7 +33,6 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   double center[3];
   double width;
   double *a = NULL;
-  double *x;
   double dist_max;
   double color_diff = 0, color_diff_old;
   double color_diff_sum = 0, color_diff_sum_old, *cc;
@@ -37,8 +40,6 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   static const int iter_max = 100;
   double cspace_size = 0.7;
   double red[3], black[3], min;
-  int imin;
-  double *wgt = NULL;
 
   assert(accuracy > 0);
   max_level = MAX(1, -log(accuracy)/log(2.));
@@ -54,7 +55,7 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   if (n == 1){
     if (scheme == COLOR_LAB){
       assert(qt);
-      QuadTree_get_nearest(qt, black, colors, &imin, &min);
+      QuadTree_get_nearest(qt, black, colors, &(int){0}, &min);
       LAB2RGB_real_01(colors);
       *color_diff0 = 1000; *color_diff_sum0 = 1000;
     } else {
@@ -65,10 +66,10 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   } else if (n == 2){
     if (scheme == COLOR_LAB){
       assert(qt);
-      QuadTree_get_nearest(qt, black, colors, &imin, &min);
+      QuadTree_get_nearest(qt, black, colors, &(int){0}, &min);
       LAB2RGB_real_01(colors);
 
-      QuadTree_get_nearest(qt, red, colors+cdim, &imin, &min);
+      QuadTree_get_nearest(qt, red, colors+cdim, &(int){0}, &min);
       LAB2RGB_real_01(colors+cdim);
       *color_diff0 = 1000; *color_diff_sum0 = 1000;
 
@@ -84,7 +85,7 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   ia = A->ia;
   ja = A->ja;
   if (A->type == MATRIX_TYPE_REAL && A->a){
-    a = (double*) A->a;
+    a = A->a;
   } 
 
   /* cube [0, cspace_size]^3: only uised if not LAB */
@@ -95,8 +96,8 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   srand(seed);
   for (i = 0; i < n*cdim; i++) colors[i] = cspace_size*drand();
 
-  x = MALLOC(sizeof(double)*cdim*n);
-  if (weightedQ) wgt = MALLOC(sizeof(double)*n);
+  double *x = gv_calloc(cdim * n, sizeof(double));
+  double *wgt = weightedQ ? gv_calloc(n, sizeof(double)) : NULL;
 
   color_diff = 0; color_diff_old = -1;
   color_diff_sum = 0; color_diff_sum_old = -1;
@@ -129,7 +130,8 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
       }
     }
 
-    if (Verbose) fprintf(stderr,"iter ---- %d ---, color_diff = %f, color_diff_sum = %f\n", iter, color_diff, color_diff_sum);
+    GV_DEBUG("iter ---- %d ---, color_diff = %f, color_diff_sum = %f", iter,
+             color_diff, color_diff_sum);
   }
 
   if (scheme == COLOR_LAB){
@@ -147,6 +149,7 @@ static void node_distinct_coloring_internal2(int scheme, QuadTree qt,
   *color_diff0 = color_diff;
   *color_diff_sum0 = color_diff_sum;
   free(x);
+  free(wgt);
 }
  
 static void node_distinct_coloring_internal(int scheme, QuadTree qt,
@@ -163,7 +166,7 @@ static void node_distinct_coloring_internal(int scheme, QuadTree qt,
     srand(123);
     iter = -seed;
     for (i = 0; i < iter; i++){
-      seed = irand(100000);
+      seed = gv_random(100000);
       node_distinct_coloring_internal2(scheme, qt, weightedQ, A, cdim, accuracy, seed, colors, &color_diff, &color_diff_sum);
       if (color_diff_max < color_diff){
 	seed_max = seed; color_diff_max = color_diff;
@@ -175,41 +178,23 @@ static void node_distinct_coloring_internal(int scheme, QuadTree qt,
  
 }
 
-int node_distinct_coloring(char *color_scheme, char *lightness, bool weightedQ,
-                           SparseMatrix A0, double accuracy, int seed,
-                           int *cdim0, double **colors) {
-  /* 
-     for a graph A, get a distinctive color of its nodes so that the color distance among all neighboring nodes are maximized. Here
-     color distance on a node is defined as the minimum of color differences between a node and its neighbors (or the minimum of weighted color differences if weightedQ = true,
-     where weights are stored as entries of A0.
-     accuracy is the threshold given so that when finding the coloring for each node, the optimal is
-     with in "accuracy" of the true global optimal. 
-     color_scheme: rgb, gray, lab, or one of the color palettes in color_palettes.h, or a list of hex rgb colors separaterd by comma like "#ff0000,#00ff00"
-     lightness: of the form 0,70, specifying the range of lightness of LAB color. Ignored if scheme is not COLOR_LAB.
-     .          if NULL, 0,70 is assumed
-     A: the graph of n nodes
-     accuracy: how accurate to find the optimal
-     seed: random_seed. If negative, consider -seed as the number of random start iterations
-     cdim: dimension of the color space
-     color: On input an array of size n*cdim, if NULL, will be allocated. On exit the final color assignment for node i is [cdim*i,cdim*(i+1)), in RGB (between 0 to 1)
-  */ 
+int node_distinct_coloring(const char *color_scheme, int *lightness,
+                           bool weightedQ, SparseMatrix A0, double accuracy,
+                           int seed, int *cdim0, double **colors) {
   SparseMatrix B, A = A0;
-  int ncomps, *comps = NULL, *comps_ptr = NULL;
+  int ncomps, *comps = NULL;
   int nn, n;
-  double *ctmp;
   int i, j, jj;
   QuadTree qt = NULL;
   int cdim;
   int scheme = COLOR_LAB;
   int maxcolors = 10000, max_qtree_level = 10, r, g, b;
-  char *color_list = NULL;
-
-  color_list = color_palettes_get(color_scheme);
+  const char *color_list = color_palettes_get(color_scheme);
   if (color_list) color_scheme = color_list;
 
   cdim = *cdim0 = 3;
   if (strcmp(color_scheme, "lab") == 0){
-    if (Verbose) fprintf(stderr,"lab\n");
+    GV_DEBUG("lab");
     scheme =  COLOR_LAB;
     qt = lab_gamut_quadtree(lightness, max_qtree_level);
     if (!qt){
@@ -217,17 +202,18 @@ int node_distinct_coloring(char *color_scheme, char *lightness, bool weightedQ,
       return -1;
     }
   } else if (strcmp(color_scheme, "rgb") == 0){
-    if (Verbose) fprintf(stderr,"rgb\n");
+    GV_DEBUG("rgb");
     scheme = COLOR_RGB;
   } else if (strcmp(color_scheme, "gray") == 0){
     scheme = COLOR_GRAY;
     cdim = *cdim0 = 1;
   } else if (sscanf(color_scheme,"#%02X%02X%02X", &r, &g, &b) == 3 ){
-    double *colors = NULL;
     scheme = COLOR_LAB;
-    color_blend_rgb2lab(color_scheme, maxcolors, &colors);
-    assert(colors);
-    qt = QuadTree_new_from_point_list(cdim, maxcolors, max_qtree_level, colors);
+    double *color_points = color_blend_rgb2lab(color_scheme, maxcolors);
+    assert(color_points);
+    qt = QuadTree_new_from_point_list(cdim, maxcolors, max_qtree_level,
+                                      color_points);
+    free(color_points);
     assert(qt);
   } else {
     return ERROR_BAD_COLOR_SCHEME;
@@ -238,18 +224,17 @@ int node_distinct_coloring(char *color_scheme, char *lightness, bool weightedQ,
 
   n = A->m;
   if (n != A->n) {
+    QuadTree_delete(qt);
     return -1;
   }
  
-  if (!(*colors)) {
-    *colors = MALLOC(sizeof(double)*cdim*n);
-  }
-  ctmp = MALLOC(sizeof(double)*cdim*n);
+  *colors = gv_calloc(cdim * n, sizeof(double));
+  double *ctmp = gv_calloc(cdim * n, sizeof(double));
 
   B = SparseMatrix_symmetrize(A, false);
   A = B;
 
-  SparseMatrix_weakly_connected_components(A, &ncomps, &comps, &comps_ptr); 
+  int *comps_ptr = SparseMatrix_weakly_connected_components(A, &ncomps, &comps);
   
   for (i = 0; i < ncomps; i++){
     nn = comps_ptr[i+1] - comps_ptr[i];
@@ -262,8 +247,11 @@ int node_distinct_coloring(char *color_scheme, char *lightness, bool weightedQ,
     }
     SparseMatrix_delete(B);
   }
+  free(comps_ptr);
   free(ctmp);
+  QuadTree_delete(qt);
 
   if (A != A0) SparseMatrix_delete(A);
+  free(comps);
   return 0;
 }
