@@ -118,9 +118,8 @@ void glCompButtonDraw(glCompButton * p)
     if (!p->base.common.visible)
 	return;
     /*draw panel */
-    glCompDrawRectPrism(&ref.pos, ref.width, ref.height,
-                        p->base.common.borderWidth, 0.01f, &ref.color,
-			!p->status);
+    glCompDrawRectPrism(ref.pos, ref.width, ref.height,
+                        p->base.common.borderWidth, ref.color, !p->status);
     if (p->label)
 	p->label->base.common.functions.draw(p->label);
     if (p->image)
