@@ -1,5 +1,5 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,7 +10,6 @@
 
 #pragma once
 
-#include <stdbool.h>
 #include <util/api.h>
 
 #ifdef __cplusplus
@@ -19,20 +18,8 @@ extern "C" {
 
 #include <neatogen/defs.h>
 
-    typedef struct {
-	int *data;
-	int queueSize;
-	int end;
-	int start;
-    } Queue;
-
-PRIVATE void mkQueue(Queue *, int);
-PRIVATE void freeQueue(Queue *);
-PRIVATE void initQueue(Queue *, int startVertex);
-PRIVATE bool deQueue(Queue *, int *);
-PRIVATE bool enQueue(Queue *, int);
-
-PRIVATE void bfs(int, vtx_data*, int, DistType*);
+/// compute vector `dist` of distances of all nodes from `vertex`
+PRIVATE void bfs(int vertex, vtx_data *graph, int n, DistType *dist);
 
 #ifdef __cplusplus
 }
