@@ -33,7 +33,7 @@ int stress_majorization_with_hierarchy(vtx_data * graph,	/* Input graph in spars
 				       int n,	/* Number of nodes */
 				       double **d_coords,	/* Coordinates of nodes (output layout)  */
 				       node_t ** nodes,	/* Original nodes */
-				       int dim,	/* Dimemsionality of layout */
+				       int dim,	/* Dimensionality of layout */
 				       int opts,	/* options */
 				       int model,	/* difference model */
 				       int maxi,	/* max iterations */
@@ -433,14 +433,10 @@ int stress_majorization_with_hierarchy(vtx_data * graph,	/* Input graph in spars
 	}
     }
 
-    if (coords != NULL) {
-	for (i = 0; i < dim; i++) {
-	    for (int j = 0; j < n; j++) {
-		d_coords[i][j] = coords[i][j];
-	    }
+    for (i = 0; i < dim; i++) {
+	for (int j = 0; j < n; j++) {
+	    d_coords[i][j] = coords[i][j];
 	}
-	free(coords[0]);
-	free(coords);
     }
 
     free(tmp_coords);
@@ -458,6 +454,8 @@ finish:
 	free(b[0]);
 	free(b);
     }
+    free(f_storage);
+    free(coords);
     free(ordering);
 
     free(levels);
