@@ -36,25 +36,40 @@ typedef DistType Word;
    data[i]=vertexNum <==> index[vertexNum]=i
 */
 
-#define left(i) (2*(i))
-#define right(i) (2*(i)+1)
-#define parent(i) ((i)/2)
-#define insideHeap(h,i) ((i)<h->heapSize)
-#define greaterPriority(h,i,j,dist) (dist[h->data[i]]<dist[h->data[j]])
-#define assign(h,i,j,index) {h->data[i]=h->data[j]; index[h->data[i]]=i;}
-#define exchange(h,i,j,index) { \
-		SWAP(&h->data[i], &h->data[j]); \
-		index[h->data[i]]=i; \
-		index[h->data[j]]=j; \
-}
+static int left(int i) { return 2 * i; }
+
+static int right(int i) { return 2 * i + 1; }
+
+static int parent(int i) { return i / 2; }
 
 typedef struct {
     int *data;
     int heapSize;
+    int *index;
 } heap;
 
-static void heapify(heap * h, int i, int index[], Word dist[])
-{
+static bool insideHeap(const heap *h, int i) { return i < h->heapSize; }
+
+static bool greaterPriority(const heap *h, int i, int j, const Word *dist) {
+  return dist[h->data[i]] < dist[h->data[j]];
+}
+
+static bool greaterPriority_f(const heap *h, int i, int j, const float *dist) {
+  return dist[h->data[i]] < dist[h->data[j]];
+}
+
+static void assign(heap *h, int i, int j) {
+  h->data[i] = h->data[j];
+  h->index[h->data[i]] = i;
+}
+
+static void exchange(heap *h, int i, int j) {
+  SWAP(&h->data[i], &h->data[j]);
+  h->index[h->data[i]] = i;
+  h->index[h->data[j]] = j;
+}
+
+static void heapify(heap *h, int i, Word dist[]) {
     int l, r, largest;
     while (1) {
 	l = left(i);
@@ -69,81 +84,77 @@ static void heapify(heap * h, int i, int index[], Word dist[])
 	if (largest == i)
 	    break;
 
-	exchange(h, largest, i, index);
+	exchange(h, largest, i);
 	i = largest;
     }
 }
 
 static void freeHeap(heap * h)
 {
+    free(h->index);
     free(h->data);
 }
 
-static void
-initHeap(heap * h, int startVertex, int index[], Word dist[], int n)
-{
+static heap initHeap(int startVertex, Word dist[], int n) {
     int i, count;
     int j;    /* We cannot use an unsigned value in this loop */
-    if (n == 1) h->data = NULL;
-    else h->data = gv_calloc(n - 1, sizeof(int));
-    h->heapSize = n - 1;
+    heap h = {
+      .data = gv_calloc(n - 1, sizeof(int)),
+      .heapSize = n - 1,
+      .index = gv_calloc(n, sizeof(int))
+    };
 
     for (count = 0, i = 0; i < n; i++)
 	if (i != startVertex) {
-	    h->data[count] = i;
-	    index[i] = count;
+	    h.data[count] = i;
+	    h.index[i] = count;
 	    count++;
 	}
 
     for (j = (n - 1) / 2; j >= 0; j--)
-	heapify(h, j, index, dist);
+	heapify(&h, j, dist);
+
+    return h;
 }
 
-static bool extractMax(heap * h, int *max, int index[], Word dist[])
-{
+static bool extractMax(heap *h, int *max, Word dist[]) {
     if (h->heapSize == 0)
 	return false;
 
     *max = h->data[0];
     h->data[0] = h->data[h->heapSize - 1];
-    index[h->data[0]] = 0;
+    h->index[h->data[0]] = 0;
     h->heapSize--;
-    heapify(h, 0, index, dist);
+    heapify(h, 0, dist);
 
     return true;
 }
 
-static void
-increaseKey(heap * h, int increasedVertex, Word newDist, int index[],
-	    Word dist[])
-{
+static void increaseKey(heap *h, int increasedVertex, Word newDist, Word dist[]) {
     int placeInHeap;
     int i;
 
     if (dist[increasedVertex] <= newDist)
 	return;
 
-    placeInHeap = index[increasedVertex];
+    placeInHeap = h->index[increasedVertex];
 
     dist[increasedVertex] = newDist;
 
     i = placeInHeap;
     while (i > 0 && dist[h->data[parent(i)]] > newDist) {	/* can write here: greaterPriority(i,parent(i),dist) */
-	assign(h, i, parent(i), index);
+	assign(h, i, parent(i));
 	i = parent(i);
     }
     h->data[i] = increasedVertex;
-    index[increasedVertex] = i;
+    h->index[increasedVertex] = i;
 }
 
 void ngdijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
 {
-    heap H;
     int closestVertex, neighbor;
     DistType closestDist, prevClosestDist = MAX_DIST;
 
-    int *index = gv_calloc(n, sizeof(int));
-
     /* initial distances with edge weights: */
     for (int i = 0; i < n; i++)
 	dist[i] = MAX_DIST;
@@ -151,16 +162,16 @@ void ngdijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
     for (size_t i = 1; i < graph[vertex].nedges; i++)
 	dist[graph[vertex].edges[i]] = (DistType) graph[vertex].ewgts[i];
 
-    initHeap(&H, vertex, index, dist, n);
+    heap H = initHeap(vertex, dist, n);
 
-    while (extractMax(&H, &closestVertex, index, dist)) {
+    while (extractMax(&H, &closestVertex, dist)) {
 	closestDist = dist[closestVertex];
 	if (closestDist == MAX_DIST)
 	    break;
 	for (size_t i = 1; i < graph[closestVertex].nedges; i++) {
 	    neighbor = graph[closestVertex].edges[i];
 	    increaseKey(&H, neighbor, closestDist +
-			(DistType)graph[closestVertex].ewgts[i], index, dist);
+			(DistType)graph[closestVertex].ewgts[i], dist);
 	}
 	prevClosestDist = closestDist;
     }
@@ -170,84 +181,82 @@ void ngdijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
 	if (dist[i] == MAX_DIST)	/* 'i' is not connected to 'vertex' */
 	    dist[i] = prevClosestDist + 10;
     freeHeap(&H);
-    free(index);
 }
 
-static void heapify_f(heap * h, int i, int index[], float dist[])
-{
+static void heapify_f(heap *h, int i, float dist[]) {
     int l, r, largest;
     while (1) {
 	l = left(i);
 	r = right(i);
-	if (insideHeap(h, l) && greaterPriority(h, l, i, dist))
+	if (insideHeap(h, l) && greaterPriority_f(h, l, i, dist))
 	    largest = l;
 	else
 	    largest = i;
-	if (insideHeap(h, r) && greaterPriority(h, r, largest, dist))
+	if (insideHeap(h, r) && greaterPriority_f(h, r, largest, dist))
 	    largest = r;
 
 	if (largest == i)
 	    break;
 
-	exchange(h, largest, i, index);
+	exchange(h, largest, i);
 	i = largest;
     }
 }
 
-static void
-initHeap_f(heap * h, int startVertex, int index[], float dist[], int n)
-{
+static heap initHeap_f(int startVertex, float dist[], int n) {
     int i, count;
     int j;			/* We cannot use an unsigned value in this loop */
-    h->data = gv_calloc(n - 1, sizeof(int));
-    h->heapSize = n - 1;
+    heap h = {
+      .data = gv_calloc(n - 1, sizeof(int)),
+      .heapSize = n - 1,
+      .index = gv_calloc(n, sizeof(int))
+    };
 
     for (count = 0, i = 0; i < n; i++)
 	if (i != startVertex) {
-	    h->data[count] = i;
-	    index[i] = count;
+	    h.data[count] = i;
+	    h.index[i] = count;
 	    count++;
 	}
 
     for (j = (n - 1) / 2; j >= 0; j--)
-	heapify_f(h, j, index, dist);
+	heapify_f(&h, j, dist);
+
+    return h;
 }
 
-static bool extractMax_f(heap * h, int *max, int index[], float dist[])
-{
+static bool extractMax_f(heap *h, int *max, float dist[]) {
     if (h->heapSize == 0)
 	return false;
 
     *max = h->data[0];
     h->data[0] = h->data[h->heapSize - 1];
-    index[h->data[0]] = 0;
+    h->index[h->data[0]] = 0;
     h->heapSize--;
-    heapify_f(h, 0, index, dist);
+    heapify_f(h, 0, dist);
 
     return true;
 }
 
-static void
-increaseKey_f(heap * h, int increasedVertex, float newDist, int index[],
-	      float dist[])
-{
+static void increaseKey_f(heap *h, int increasedVertex, float newDist,
+                          float dist[]) {
     int placeInHeap;
     int i;
 
     if (dist[increasedVertex] <= newDist)
 	return;
 
-    placeInHeap = index[increasedVertex];
+    placeInHeap = h->index[increasedVertex];
 
     dist[increasedVertex] = newDist;
 
     i = placeInHeap;
     while (i > 0 && dist[h->data[parent(i)]] > newDist) {	/* can write here: greaterPriority(i,parent(i),dist) */
-	assign(h, i, parent(i), index);
+	assign(h, i, parent(i));
 	i = parent(i);
     }
     h->data[i] = increasedVertex;
-    index[increasedVertex] = i;
+    h->index[increasedVertex] = i;
 }
 
 /* Weighted shortest paths from vertex.
@@ -255,10 +264,8 @@ increaseKey_f(heap * h, int increasedVertex, float newDist, int index[],
  */
 void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
 {
-    heap H;
     int closestVertex = 0, neighbor;
     float closestDist;
-    int *index = gv_calloc(n, sizeof(int));
 
     /* initial distances with edge weights: */
     for (int i = 0; i < n; i++)
@@ -267,29 +274,26 @@ void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
     for (size_t i = 1; i < graph[vertex].nedges; i++)
 	dist[graph[vertex].edges[i]] = graph[vertex].ewgts[i];
 
-    initHeap_f(&H, vertex, index, dist, n);
+    heap H = initHeap_f(vertex, dist, n);
 
-    while (extractMax_f(&H, &closestVertex, index, dist)) {
+    while (extractMax_f(&H, &closestVertex, dist)) {
 	closestDist = dist[closestVertex];
 	if (closestDist == FLT_MAX)
 	    break;
 	for (size_t i = 1; i < graph[closestVertex].nedges; i++) {
 	    neighbor = graph[closestVertex].edges[i];
 	    increaseKey_f(&H, neighbor, closestDist + graph[closestVertex].ewgts[i],
-			  index, dist);
+			  dist);
 	}
     }
 
     freeHeap(&H);
-    free(index);
 }
 
 // single source shortest paths that also builds terms as it goes
 // mostly copied from dijkstra_f above
 // returns the number of terms built
 int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
-    heap h;
-    int *indices = gv_calloc(graph->n, sizeof(int));
     float *dists = gv_calloc(graph->n, sizeof(float));
     for (size_t i= 0; i < graph->n; i++) {
         dists[i] = FLT_MAX;
@@ -301,10 +305,10 @@ int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
         dists[target] = graph->weights[i];
     }
     assert(graph->n <= INT_MAX);
-    initHeap_f(&h, source, indices, dists, (int)graph->n);
+    heap h = initHeap_f(source, dists, (int)graph->n);
 
     int closest = 0, offset = 0;
-    while (extractMax_f(&h, &closest, indices, dists)) {
+    while (extractMax_f(&h, &closest, dists)) {
         float d = dists[closest];
         if (d == FLT_MAX) {
             break;
@@ -323,11 +327,10 @@ int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
             size_t target = graph->targets[i];
             float weight = graph->weights[i];
             assert(target <= INT_MAX);
-            increaseKey_f(&h, (int)target, d+weight, indices, dists);
+            increaseKey_f(&h, (int)target, d+weight, dists);
         }
     }
     freeHeap(&h);
-    free(indices);
     free(dists);
     return offset;
 }
