@@ -14,9 +14,11 @@
 #include <limits.h>
 #include <neatogen/neato.h>
 #include <pathplan/pathutil.h>
+#include <stdbool.h>
 #include <stddef.h>
 #include <util/alloc.h>
 #include <util/exit.h>
+#include <util/list.h>
 
 #define SLOPE(p,q) ( ( ( p.y ) - ( q.y ) ) / ( ( p.x ) - ( q.x ) ) )
 
@@ -25,13 +27,12 @@
 #define after(v) (((v)==((v)->poly->finish))?((v)->poly->start):((v)+1))
 #define prior(v) (((v)==((v)->poly->start))?((v)->poly->finish):((v)-1))
 
-typedef struct active_edge active_edge;
 typedef struct polygon polygon;
 
-    typedef struct {
+    typedef struct vertex {
 	pointf pos;
 	polygon *poly;
-	active_edge *active;
+	struct vertex *active;
     } vertex ;
 
     struct polygon {
@@ -39,18 +40,6 @@ typedef struct polygon polygon;
 	boxf bb;
     };
 
-    struct active_edge {
-	vertex *name;
-	struct active_edge *next, *last;
-    };
-    typedef struct active_edge_list {
-	active_edge *first, *final;
-	int number;
-    } active_edge_list ;
-    typedef struct {
-	int nvertices, ninters;
-    } data ;
-
 static int sign(double v) {
   if (v < 0)
     return -1;
@@ -198,18 +187,12 @@ putSeg (int i, vertex* v)
 	i, v->pos.x, v->pos.y, after(v)->pos.x, after(v)->pos.y);
 }
 
-/* realIntersect:
- * Return 1 if a real intersection has been found
- */
-static int
-realIntersect (vertex *firstv, vertex *secondv, pointf p)
-{
-    pointf vft, vsd, avft, avsd;
-
-    vft = firstv->pos;
-    avft = after(firstv)->pos;
-    vsd = secondv->pos;
-    avsd = after(secondv)->pos;
+/// return true if a real intersection has been found
+static bool realIntersect(vertex *firstv, vertex *secondv, pointf p) {
+    const pointf vft = firstv->pos;
+    const pointf avft = after(firstv)->pos;
+    const pointf vsd = secondv->pos;
+    const pointf avsd = after(secondv)->pos;
 
     if ((vft.x != avft.x && vsd.x != avsd.x) ||
 	(vft.x == avft.x && !EQ_PT(vft, p) && !EQ_PT(avft, p)) ||
@@ -221,40 +204,36 @@ realIntersect (vertex *firstv, vertex *secondv, pointf p)
 		putSeg (1, firstv);
 		putSeg (2, secondv);
 	}
-	return 1;
+	return true;
     }
-    else return 0;
+    return false;
 }
 
-/* find_intersection:
- * detect whether segments l and m intersect      
- * Return 1 if found; 0 otherwise;
+/* detect whether segments l and m intersect      
+ * Return true if found; false otherwise;
  */
-static int find_intersection(vertex *l, vertex *m) {
+static bool find_intersection(vertex *l, vertex *m) {
     double x, y;
-    pointf p;
 	int i[3];
     sgnarea(l, m, i);
 
     if (i[2] > 0)
-	return 0;
+	return false;
 
     if (i[2] < 0) {
 	sgnarea(m, l, i);
 	if (i[2] > 0)
-	    return 0;
+	    return false;
 	if (!intpoint(l, m, &x, &y, i[2] < 0 ? 3 : online(m, l, abs(i[0]))))
-	    return 0;
+	    return false;
     }
 
     else if (!intpoint(l, m, &x, &y, i[0] == i[1] ?
 		       2 * MAX(online(l, m, 0),
 			       online(l, m, 1)) : online(l, m, abs(i[0]))))
-	return 0;
+	return false;
 
-    p.x = x;
-    p.y = y;
-    return realIntersect(l, m, p);
+    return realIntersect(l, m, (pointf){.x = x, .y = y});
 }
 
 static int gt(const void *a, const void *b) {
@@ -275,18 +254,13 @@ static int gt(const void *a, const void *b) {
     return 0;
 }
 
-/* find_ints:
- * Check for pairwise intersection of polygon sides
+/* Check for pairwise intersection of polygon sides
  * Return 1 if intersection found, 0 for not found, -1 for error.
  */
 static int find_ints(vertex vertex_list[], size_t nvertices) {
-    int j, k, found = 0;
-    active_edge_list all;
-    active_edge *new, *tempa;
-    vertex *pt1, *pt2, *templ;
-
-    all.first = all.final = 0;
-    all.number = 0;
+    int found = 0;
+    LIST(vertex *) all = {0};
+    vertex *tempa;
 
     vertex **pvertex = gv_calloc(nvertices, sizeof(vertex*));
 
@@ -298,38 +272,25 @@ static int find_ints(vertex vertex_list[], size_t nvertices) {
 
 /* walk through the vertices in order of increasing x coordinate	*/
     for (size_t i = 0; i < nvertices; i++) {
-	pt1 = pvertex[i];
-	templ = pt2 = prior(pvertex[i]);
-	for (k = 0; k < 2; k++) {	/* each vertex has 2 edges */
+	vertex *const pt1 = pvertex[i];
+	vertex *pt2 = prior(pvertex[i]);
+	vertex *templ = pt2;
+	for (int k = 0; k < 2; k++) { // each vertex has 2 edges
 	    switch (gt(&pt1, &pt2)) {
 
 	    case -1:		/* forward edge, test and insert      */
 
                  /* test */
-		for (tempa = all.first, j = 0; j < all.number;
-		     j++, tempa = tempa->next) {
-		    found = find_intersection(tempa->name, templ);
+		for (size_t j = 0; j < LIST_SIZE(&all); ++j) {
+		    tempa = LIST_GET(&all, j);
+		    found = find_intersection(tempa, templ);
 		    if (found)
 			goto finish;
 		}
 
-		new = gv_alloc(sizeof(active_edge));
-		if (all.number == 0) {
-		    all.first = new;
-		    new->last = 0;
-		} /* insert */
-		else {
-		    all.final->next = new;
-		    new->last = all.final;
-		}
-
-		new->name = templ;
-		new->next = 0;
-		templ->active = new;
-		all.final = new;
-		all.number++;
-
-		break;		/* end of case -1       */
+		LIST_APPEND(&all, templ);
+		templ->active = templ;
+		break;
 
 	    case 1:		/* backward edge, delete        */
 
@@ -337,39 +298,22 @@ static int find_ints(vertex vertex_list[], size_t nvertices) {
 		    agerrorf("trying to delete a non-line\n");
 		    return -1;
 		}
-		if (all.number == 1)
-		    all.final = all.first = 0;	/* delete the line */
-		else if (tempa == all.first) {
-		    all.first = all.first->next;
-		    all.first->last = 0;
-		} else if (tempa == all.final) {
-		    all.final = all.final->last;
-		    all.final->next = 0;
-		} else {
-		    tempa->last->next = tempa->next;
-		    tempa->next->last = tempa->last;
-		}
-		free(tempa);
-		all.number--;
+		LIST_REMOVE(&all, tempa);
 		templ->active = 0;
-		break;		/* end of case 1        */
+		break;
 
 	    default:
 		break; // same point; do nothing
 
-	    }			/* end switch   */
+	    }
 
 	    pt2 = after(pvertex[i]);
 	    templ = pvertex[i];	/*second neighbor */
-	}			/* end k for loop       */
-    }				/* end i for loop       */
+	}
+    }
 
 finish :
-    for (tempa = all.first, j = 0; j < all.number;
-		     j++, tempa = new) {
-	new = tempa->next;
-	free (tempa);
-    }
+    LIST_FREE(&all);
     free (pvertex);
     return found;
 }
@@ -377,8 +321,7 @@ finish :
 #define INBOX(p,bb) ((p.x <= bb.UR.x) && (p.x >= bb.LL.x) && (p.y <= bb.UR.y) && (p.y >= bb.LL.y))
 #define NESTED(a,b) (INBOX(a.LL,b) && INBOX(a.UR,b))
 
-/* findInside:
- * Check if one polygon is inside another. We know that each
+/* Check if one polygon is inside another. We know that each
  * pair is either disjoint or one is inside the other.
  * Return 1 if an intersection is found, 0 otherwise.
  */
@@ -406,8 +349,7 @@ findInside(Ppoly_t ** polys, int n_polys, polygon* polygon_list)
     return 0;
 }
 
-/* Plegal_arrangement:
- * Check that none of the polygons overlap.
+/* Check that none of the polygons overlap.
  * Return 1 if okay; 0 otherwise.
  */
 int Plegal_arrangement(Ppoly_t ** polys, int n_polys)
