@@ -70,8 +70,6 @@ static int cmpItem(void *item1, void *item2) {
     return 0;
 }
 
-/* newItem:
- */
 static void *newItem(void *p, Dtdisc_t *disc) {
     item *objp = p;
     item *newp = gv_alloc(sizeof(item));
@@ -105,8 +103,7 @@ static void addMap(Dt_t * map, int a, int b, int t)
     dtinsert(map, &it);
 }
 
-/* mapSegToTri:
- * Create mapping from indices of side endpoints to triangle id 
+/* Create mapping from indices of side endpoints to triangle id 
  * We use a set rather than a bag because the segments used for lookup
  * will always be a side of a polygon and hence have a unique triangle.
  */
@@ -197,9 +194,7 @@ static int vMap(Dt_t * map, int i)
     return ip->j;
 }
 
-/* mapTri:
- * Map vertex indices from router_t to tripoly_t coordinates.
- */
+/// map vertex indices from router_t to tripoly_t coordinates
 static void mapTri(Dt_t * map, tri * tp)
 {
     for (; tp; tp = tp->nxttri) {
@@ -208,8 +203,6 @@ static void mapTri(Dt_t * map, tri * tp)
     }
 }
 
-/* addTri:
- */
 static tri *
 addTri(int i, int j, tri * oldp)
 {
@@ -220,9 +213,7 @@ addTri(int i, int j, tri * oldp)
     return tp;
 }
 
-/* bisect:
- * Return the angle bisecting the angle pp--cp--np
- */
+/// return the angle bisecting the angle pp--cp--np
 static double bisect(pointf pp, pointf cp, pointf np)
 {
     double theta, phi;
@@ -231,9 +222,7 @@ static double bisect(pointf pp, pointf cp, pointf np)
     return (theta + phi) / 2.0;
 }
 
-/* raySeg:
- * Check if ray v->w intersects segment a--b.
- */
+/// check if ray v->w intersects segment a--b
 static int raySeg(pointf v, pointf w, pointf a, pointf b)
 {
     int wa = wind(v, w, a);
@@ -247,8 +236,7 @@ static int raySeg(pointf v, pointf w, pointf a, pointf b)
     }
 }
 
-/* raySegIntersect:
- * Find the point p where ray v->w intersects segment ai-bi, if any.
+/* Find the point p where ray v->w intersects segment ai-bi, if any.
  * Return 1 on success, 0 on failure
  */
 static int
@@ -260,8 +248,7 @@ raySegIntersect(pointf v, pointf w, pointf a, pointf b, pointf * p)
 	return 0;
 }
 
-/* triPoint:
- * Given the triangle vertex v, and point w so that v->w points
+/* Given the triangle vertex v, and point w so that v->w points
  * into the polygon, return where the ray v->w intersects the
  * polygon. The search uses all of the opposite sides of triangles
  * with v as vertex.
@@ -280,8 +267,7 @@ triPoint(tripoly_t * trip, int vx, pointf v, pointf w, pointf * ip)
     return 1;
 }
 
-/* ctrlPtIdx:
- * Find the index of v in the points polys->ps.
+/* Find the index of v in the points polys->ps.
  * We start at 1 since the point corresponding to 0 
  * will never be used as v.
  */
@@ -300,10 +286,9 @@ static int ctrlPtIdx(pointf v, Ppoly_t * polys)
 
 #define SEP 15
 
-/* mkCtrlPts:
- * Generate mult points associated with v.
+/* Generate mult points associated with v.
  * The points will lie on the ray bisecting the angle prev--v--nxt.
- * The first point will aways be v.
+ * The first point will always be v.
  * The rest are positioned equally spaced with maximum spacing SEP.
  * In addition, they all lie within the polygon trip->poly.
  * Parameter s gives the index after which a vertex lies on the
@@ -342,6 +327,7 @@ static pointf *mkCtrlPts(int s, int mult, pointf prev, pointf v,
     }
 
     if (triPoint(trip, idx, v, w, &q)) {
+	free(ps);
 	return 0;
     }
 
@@ -394,11 +380,10 @@ struct router_s {
     int *tris;	/* indices of triangle i are tris[3*i]...tris[3*i+2] */
     Dt_t *trimap; /* map from obstacle side (a,b) to index of adj. triangle */
     int tn;	  /* no. of nodes in tg */
-    tgraph *tg;	  /* graph of triangles */
+    tgraph tg;	  /* graph of triangles */
 };
 
-/* triCenter:
- * Given an array of points and 3 integer indices,
+/* Given an array of points and 3 integer indices,
  * compute and return the center of the triangle.
  */
 static pointf triCenter(pointf * pts, int *idxs)
@@ -414,8 +399,7 @@ static pointf triCenter(pointf * pts, int *idxs)
 
 #define MARGIN 32
 
-/* bbox:
- * Compute bounding box of polygons, and return it
+/* Compute bounding box of polygons, and return it
  * with an added margin of MARGIN.
  * Store total number of points in *np.
  */
@@ -458,8 +442,7 @@ static int *mkTriIndices(surface_t * sf)
     return tris;
 }
 
-/* sharedEdge:
- * Returns a pair of integer (x,y), x < y, where x and y are the
+/* Returns a pair of integer (x,y), x < y, where x and y are the
  * indices of the two vertices of the shared edge.
  */
 static ipair sharedEdge(int *p, int *q)
@@ -492,8 +475,7 @@ static ipair sharedEdge(int *p, int *q)
     return pt;
 }
 
-/* addTriEdge:
- * Add an edge to g, with tail t, head h, and shared
+/* Add an edge to g, with tail t, head h, and shared
  * segment seg.
  */
 static void addTriEdge(tgraph *g, int t, int h, ipair seg) {
@@ -525,45 +507,34 @@ static void freeTriGraph(tgraph * tg)
     }
     free(tg->nodes);
     free(tg->edges);
-    free(tg);
+    *tg = (tgraph){0};
 }
 
-/* mkTriGraph:
- * Generate graph with triangles as nodes and an edge iff two triangles
+/* Generate graph with triangles as nodes and an edge iff two triangles
  * share an edge.
  */
-static tgraph *mkTriGraph(surface_t *sf, pointf *pts) {
-    tnode *np;
-    int j, i, ne = 0;
-    int *jp;
+static tgraph mkTriGraph(surface_t *sf, pointf *pts) {
+    int j;
 
-    /* ne is twice no. of edges */
-    for (i = 0; i < 3 * sf->nfaces; i++)
-	if (sf->neigh[i] != -1)
-	    ne++;
-
-    tgraph *g = gv_alloc(sizeof(tgraph));
+    tgraph g = {0};
 
     /* plus 2 for nodes added as endpoints of an edge */
-    g->nnodes = sf->nfaces + 2;
-    g->nodes = gv_calloc(g->nnodes, sizeof(tnode));
+    g.nnodes = sf->nfaces + 2;
+    g.nodes = gv_calloc(g.nnodes, sizeof(tnode));
 
-    for (i = 0; i < sf->nfaces; i++) {
-	np = g->nodes + i;
+    for (int i = 0; i < sf->nfaces; i++) {
+	tnode *const np = g.nodes + i;
 	np->ctr = triCenter(pts, sf->faces + 3 * i);
     }
 
-    for (i = 0; i < sf->nfaces; i++) {
-	np = g->nodes + i;
-	jp = sf->neigh + 3 * i;
-        ne = 0;
-	while (ne < 3 && (j = *jp++) != -1) {
+    for (int i = 0; i < sf->nfaces; i++) {
+	int *jp = sf->neigh + 3 * i;
+	for (int ne = 0; ne < 3 && (j = *jp++) != -1; ++ne) {
 	    if (i < j) {
 		ipair seg =
 		    sharedEdge(sf->faces + 3 * i, sf->faces + 3 * j);
-		addTriEdge(g, i, j, seg);
+		addTriEdge(&g, i, j, seg);
 	    }
-	    ne++;
 	}
     }
 
@@ -576,7 +547,7 @@ void freeRouter(router_t * rtr)
     free(rtr->obs);
     free(rtr->tris);
     dtclose(rtr->trimap);
-    freeTriGraph(rtr->tg);
+    freeTriGraph(&rtr->tg);
     free(rtr);
 }
 
@@ -651,8 +622,7 @@ router_t *mkRouter(Ppoly_t** obsp, int npoly)
     return rtr;
 }
 
-/* finishEdge:
- * Finish edge generation, clipping to nodes and adding arrowhead
+/* Finish edge generation, clipping to nodes and adding arrowhead
  * if necessary, and adding edge labels
  */
 static void finishEdge(edge_t* e, Ppoly_t spl, int flip) {
@@ -670,8 +640,7 @@ static void finishEdge(edge_t* e, Ppoly_t spl, int flip) {
 
 #define EQPT(p,q) (((p).x==(q).x)&&((p).y==(q).y))
 
-/* tweakEnd:
- * Hack because path routing doesn't know about the interiors
+/* Hack because path routing doesn't know about the interiors
  * of polygons. If the first or last segment of the shortest path
  * lies along one of the polygon boundaries, the path may flip
  * inside the polygon. To avoid this, we shift the point a bit.
@@ -710,14 +679,12 @@ static void tweakPath(Ppoly_t poly, size_t t, Ppolyline_t pl) {
 }
 
 
-/* genroute:
- * Generate splines for e and cohorts.
+/* Generate splines for e and cohorts.
  * Edges go from 0 to t.
  * Return 0 on success.
  */
 static int genroute(tripoly_t *trip, int t, edge_t *e, int doPolyline) {
     pointf eps[2];
-    Pvector_t evs[2];
     pointf **cpts = NULL;		/* lists of control points */
     Ppoly_t poly;
     Ppolyline_t pl, spl;
@@ -741,9 +708,6 @@ static int genroute(tripoly_t *trip, int t, edge_t *e, int doPolyline) {
 	goto finish;
     }
 
-    evs[0].x = evs[0].y = 0;
-    evs[1].x = evs[1].y = 0;
-
     if (mult == 1 || Concentrate) {
 	poly = trip->poly;
 	Pedge_t *medges = gv_calloc(poly.pn, sizeof(Pedge_t));
@@ -753,7 +717,7 @@ static int genroute(tripoly_t *trip, int t, edge_t *e, int doPolyline) {
 	}
 	assert(t >= 0);
 	tweakPath(poly, (size_t)t, pl);
-	if (Proutespline(medges, poly.pn, pl, evs, &spl) < 0) {
+	if (Proutespline(medges, poly.pn, pl, (Pvector_t[2]){0}, &spl) < 0) {
 	    agwarningf("Could not create control points for multiple spline for edge (%s,%s)\n", agnameof(agtail(e)), agnameof(aghead(e)));
 	    rv = 1;
 	    goto finish;
@@ -805,7 +769,8 @@ static int genroute(tripoly_t *trip, int t, edge_t *e, int doPolyline) {
 		medges[j].b = poly.ps[(j + 1) % poly.pn];
 	    }
 	    tweakPath(poly, pl.pn - 1, mmpl);
-	    const bool failed_routing = Proutespline(medges, poly.pn, mmpl, evs, &spl) < 0;
+	    const bool failed_routing =
+	      Proutespline(medges, poly.pn, mmpl, (Pvector_t[2]){0}, &spl) < 0;
 	    free(medges);
 	    if (failed_routing) {
 		agwarningf("Could not create control points for multiple spline for edge (%s,%s)\n", 
@@ -831,9 +796,7 @@ finish :
 
 #define NSMALL -0.0000000001
 
-/* inCone:
- * Returns true iff q is in the convex cone a-b-c
- */
+/// returns true iff q is in the convex cone a-b-c
 static int
 inCone (pointf a, pointf b, pointf c, pointf q)
 {
@@ -849,8 +812,7 @@ static pointf southwest = {-1, -1};
 static pointf west = {-1, 0};
 static pointf northwest = {-1, 1};
 
-/* addEndpoint:
- * Add node to graph representing spline end point p inside obstruction obs_id.
+/* Add node to graph representing spline end point p inside obstruction obs_id.
  * For each side of obstruction, add edge from p to corresponding triangle.
  * The node id of the new node in the graph is v_id.
  * If p lies on the side of its node (sides != 0), we limit the triangles
@@ -913,8 +875,8 @@ static void addEndpoint(router_t * rtr, pointf p, node_t* v, int v_id, int sides
 	break;
     }
 
-    rtr->tg->nodes[v_id].ne = 0;
-    rtr->tg->nodes[v_id].ctr = p;
+    rtr->tg.nodes[v_id].ne = 0;
+    rtr->tg.nodes[v_id].ctr = p;
     for (i = starti; i < endi; i++) {
 	ipair seg;
 	seg.i = i;
@@ -925,27 +887,25 @@ static void addEndpoint(router_t * rtr, pointf p, node_t* v, int v_id, int sides
 	t = findMap(rtr->trimap, seg.i, seg.j);
 	if (sides && !inCone (v0, p, v1, pts[seg.i]) && !inCone (v0, p, v1, pts[seg.j]) && !raySeg(p,vr,pts[seg.i],pts[seg.j]))
 	    continue;
-	addTriEdge(rtr->tg, v_id, t, seg);
+	addTriEdge(&rtr->tg, v_id, t, seg);
     }
-    assert(rtr->tg->nodes[v_id].ne > 0 && "no edges were added");
+    assert(rtr->tg.nodes[v_id].ne > 0 && "no edges were added");
 }
 
-/* edgeToSeg:
- * Given edge from i to j, find segment associated
+/* Given edge from i to j, find segment associated
  * with the edge.
  *
  * This lookup could be made faster by modifying the 
  * shortest path algorithm to store the edges rather than
  * the nodes.
  */
-static ipair edgeToSeg(tgraph * tg, int i, int j)
-{
+static ipair edgeToSeg(tgraph tg, int i, int j) {
     ipair ip = {0, 0};
-    tnode *np = tg->nodes + i;
+    tnode *np = tg.nodes + i;
     tedge *ep;
 
     for (size_t k = 0; k < np->ne; k++) {
-	ep = tg->edges + np->edges[k];
+	ep = tg.edges + np->edges[k];
 	if (ep->t == j || ep->h == j)
 	    return ep->seg;
     }
@@ -983,8 +943,7 @@ typedef struct {
     tri *ts;
 } side_t;
 
-/* mkPoly:
- * Construct simple polygon from shortest path from t to s in g.
+/* Construct simple polygon from shortest path from t to s in g.
  * dad gives the indices of the triangles on path.
  * sx used to store index of s in points.
  * index of t is always 0
@@ -1099,14 +1058,12 @@ static tripoly_t *mkPoly(router_t * rtr, int *dad, int s, int t,
     return ps;
 }
 
-/* resetGraph:
- * Remove edges and nodes added for current edge routing
- */
-static void resetGraph(tgraph *g, int ncnt, int ecnt,
+/// remove edges and nodes added for current edge routing
+static void resetGraph(tgraph g, int ncnt, int ecnt,
                        size_t *original_edge_count) {
     int i;
-    tnode *np = g->nodes;
-    g->nedges = ecnt;
+    tnode *np = g.nodes;
+    g.nedges = ecnt;
     for (i = 0; i < ncnt; i++) {
 	np->ne = original_edge_count[i];
 	np++;
@@ -1137,15 +1094,12 @@ typedef struct {
 #define E_WT(e) (e->dist)
 #define UNSEEN (-FLT_MAX)
 
-/* triPath:
- * Find the shortest path with lengths in g from
+/* Find the shortest path with lengths in g from
  * v0 to v1. The returned vector (dad) encodes the
  * shorted path from v1 to v0. That path is given by
  * v1, dad[v1], dad[dad[v1]], ..., v0.
  */
-static int *
-triPath(tgraph * g, int n, int v0, int v1, PQ * pq)
-{
+static int *triPath(tgraph g, int n, int v0, int v1, PQ *pq) {
     int i, adjn;
     double d;
     tnode *np;
@@ -1165,9 +1119,9 @@ triPath(tgraph * g, int n, int v0, int v1, PQ * pq)
 	N_VAL(pq, i) *= -1;
 	if (i == v1)
 	    break;
-	np = g->nodes + i;
+	np = g.nodes + i;
 	for (size_t j = 0; j < np->ne; j++) {
-	    e = g->edges + np->edges[j];
+	    e = g.edges + np->edges[j];
 	    if (e->t == i)
 		adjn = e->h;
 	    else
@@ -1191,8 +1145,7 @@ triPath(tgraph * g, int n, int v0, int v1, PQ * pq)
     return dad;
 }
 
-/* makeMultiSpline:
- * FIX: we don't really use the shortest path provided by ED_path,
+/* FIX: we don't really use the shortest path provided by ED_path,
  * so avoid in neato spline code.
  * Return 0 on success.
  */
@@ -1207,16 +1160,16 @@ int makeMultiSpline(edge_t* e, router_t * rtr, int doPolyline) {
     int *sp;
     int t_id = rtr->tn;
     int h_id = rtr->tn + 1;
-    int ecnt = rtr->tg->nedges;
+    int ecnt = rtr->tg.nedges;
     PPQ pq;
     int ret;
 
     // record the number of edges in each node, so we can drop the added ones
     // later
-    size_t *original_edge_count = gv_calloc(rtr->tg->nnodes,
+    size_t *original_edge_count = gv_calloc(rtr->tg.nnodes,
                                             sizeof(original_edge_count[0]));
-    for (size_t i = 0; i < rtr->tg->nnodes; ++i)
-        original_edge_count[i] = rtr->tg->nodes[i].ne;
+    for (size_t i = 0; i < rtr->tg.nnodes; ++i)
+        original_edge_count[i] = rtr->tg.nodes[i].ne;
 
 	/* Add endpoints to triangle graph */
     addEndpoint(rtr, t_p, t, t_id, ED_tail_port(e).side);
