@@ -12,20 +12,15 @@
 
 #include <sfdpgen/post_process.h>
 #include <stdbool.h>
-
-#if !defined(__CYGWIN__) && defined(__GNUC__) && !defined(__MINGW32__)
-#define INTERNAL __attribute__((visibility("hidden")))
-#else
-#define INTERNAL /* nothing */
-#endif
+#include <util/api.h>
 
 typedef  StressMajorizationSmoother OverlapSmoother;
 
 #define OverlapSmoother_struct StressMajorizationSmoother_struct
 
-INTERNAL void OverlapSmoother_delete(OverlapSmoother sm);
+PRIVATE void OverlapSmoother_delete(OverlapSmoother sm);
 
-INTERNAL OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m, int dim, double *x,
+PRIVATE OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m, int dim, double *x,
                                     double *width, bool neighborhood_only,
                                     double *max_overlap, double *min_overlap,
                                     int edge_labeling_scheme,
@@ -54,11 +49,9 @@ struct relative_position_constraints_struct{
 
 typedef struct relative_position_constraints_struct*  relative_position_constraints;
 
-INTERNAL double OverlapSmoother_smooth(OverlapSmoother sm, int dim, double *x);
+PRIVATE double OverlapSmoother_smooth(OverlapSmoother sm, int dim, double *x);
 
-INTERNAL void remove_overlap(int dim, SparseMatrix A, double *x, double *label_sizes,
+PRIVATE void remove_overlap(int dim, SparseMatrix A, double *x, double *label_sizes,
                     int ntry, double initial_scaling, int edge_labeling_scheme,
                     int n_constr_nodes, int *constr_nodes,
                     SparseMatrix A_constr, bool doShrink);
-
-#undef INTERNAL
