@@ -8,29 +8,11 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <neatogen/mem.h>
 #include <neatogen/site.h>
 #include <math.h>
 
-
-int siteidx;
 Site *bottomsite;
 
-static Freelist sfl;
-static size_t nvertices;
-
-void siteinit(void)
-{
-    freeinit(&sfl, sizeof(Site));
-    nvertices = 0;
-}
-
-
-Site *getsite(void)
-{
-    return getfree(&sfl);
-}
-
 double ngdist(Site * s, Site * t)
 {
     double ans;
@@ -41,22 +23,3 @@ double ngdist(Site * s, Site * t)
     ans = hypot(dx, dy);
     return ans;
 }
-
-
-void makevertex(Site * v)
-{
-    v->sitenbr = nvertices;
-    ++nvertices;
-}
-
-void deref(Site * v)
-{
-    --v->refcnt;
-    if (v->refcnt == 0)
-	makefree(v, &sfl);
-}
-
-void ref(Site * v)
-{
-    ++v->refcnt;
-}
