@@ -8,7 +8,6 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <neatogen/mem.h>
 #include <neatogen/geometry.h>
 #include <neatogen/edges.h>
 #include <neatogen/hedges.h>
@@ -25,8 +24,6 @@ void voronoi(Site *(*nextsite)(void *context), void *context) {
     Halfedge *lbnd, *rbnd, *llbnd, *rrbnd, *bisector;
     Edge *e;
 
-    LIST(Edge *) allocated = {0}; // live edges to be freed
-    siteinit();
     pq_t *pq = PQinitialize();
     bottomsite = nextsite(context);
     el_state_t st = {0};
@@ -44,18 +41,17 @@ void voronoi(Site *(*nextsite)(void *context), void *context) {
 	    lbnd = ELleftbnd(&st, &newsite->coord);
 	    rbnd = ELright(lbnd);
 	    bot = rightreg(lbnd);
-	    e = gvbisect(bot, newsite);
-	    LIST_APPEND(&allocated, e);
+	    e = gvbisect(bot, newsite, &st.allocated);
 	    bisector = HEcreate(&st, e, le);
 	    ELinsert(lbnd, bisector);
-	    if ((p = hintersect(lbnd, bisector)) != NULL) {
+	    if ((p = hintersect(lbnd, bisector, &st.allocated)) != NULL) {
 		PQdelete(pq, lbnd);
 		PQinsert(pq, lbnd, p, ngdist(p, newsite));
 	    }
 	    lbnd = bisector;
 	    bisector = HEcreate(&st, e, re);
 	    ELinsert(lbnd, bisector);
-	    if ((p = hintersect(bisector, rbnd)) != NULL)
+	    if ((p = hintersect(bisector, rbnd, &st.allocated)) != NULL)
 		PQinsert(pq, bisector, p, ngdist(p, newsite));
 	    newsite = nextsite(context);
 	} else if (!PQempty(pq)) {
@@ -67,13 +63,8 @@ void voronoi(Site *(*nextsite)(void *context), void *context) {
 	    bot = leftreg(lbnd);
 	    top = rightreg(rbnd);
 	    v = lbnd->vertex;
-	    makevertex(v);
-	    if (endpoint(lbnd->ELedge, lbnd->ELpm, v)) {
-		LIST_REMOVE(&allocated, lbnd->ELedge);
-	    }
-	    if (endpoint(rbnd->ELedge, rbnd->ELpm, v)) {
-		LIST_REMOVE(&allocated, rbnd->ELedge);
-	    }
+	    endpoint(lbnd->ELedge, lbnd->ELpm, v, &st.allocated);
+	    endpoint(rbnd->ELedge, rbnd->ELpm, v, &st.allocated);
 	    ELdelete(lbnd);
 	    PQdelete(pq, rbnd);
 	    ELdelete(rbnd);
@@ -82,19 +73,15 @@ void voronoi(Site *(*nextsite)(void *context), void *context) {
 		SWAP(&bot, &top);
 		pm = re;
 	    }
-	    e = gvbisect(bot, top);
-	    LIST_APPEND(&allocated, e);
+	    e = gvbisect(bot, top, &st.allocated);
 	    bisector = HEcreate(&st, e, pm);
 	    ELinsert(llbnd, bisector);
-	    if (endpoint(e, re - pm, v)) {
-		LIST_REMOVE(&allocated, e);
-	    }
-	    deref(v);
-	    if ((p = hintersect(llbnd, bisector)) != NULL) {
+	    endpoint(e, re - pm, v, &st.allocated);
+	    if ((p = hintersect(llbnd, bisector, &st.allocated)) != NULL) {
 		PQdelete(pq, llbnd);
 		PQinsert(pq, llbnd, p, ngdist(p, bot));
 	    }
-	    if ((p = hintersect(bisector, rrbnd)) != NULL) {
+	    if ((p = hintersect(bisector, rrbnd, &st.allocated)) != NULL) {
 		PQinsert(pq, bisector, p, ngdist(p, bot));
 	    }
 	} else
@@ -112,9 +99,4 @@ void voronoi(Site *(*nextsite)(void *context), void *context) {
     // `PQcleanup` relies on the number of sites, so should be discarded and
     // at least every time we use `vAdjust`. See note in adjust.c:cleanup().
     PQcleanup(pq);
-
-    for (size_t i = 0; i < LIST_SIZE(&allocated); ++i) {
-	free(LIST_GET(&allocated, i));
-    }
-    LIST_FREE(&allocated);
 }
