@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -11,8 +11,8 @@
 /* Priority Queue Code for shortest path in graph */
 
 #include "config.h"
-#include <common/memory.h>
 #include <assert.h>
+#include <util/alloc.h>
 
 #include <ortho/fPQ.h>
 
@@ -25,7 +25,7 @@ void
 PQgen(int sz)
 {
   if (!pq) {
-    pq = N_NEW(sz+1,snode*);
+    pq = gv_calloc(sz + 1, sizeof(snode*));
     pq[0] = &guard;
     PQsize = sz;
   }
@@ -80,7 +80,7 @@ int
 PQ_insert(snode* np)
 {
   if (PQcnt == PQsize) {
-    agerr (AGERR, "Heap overflow\n");
+    agerrorf("Heap overflow\n");
     return 1;
   }
   PQcnt++;
