@@ -62,6 +62,47 @@ typedef struct {
   int marked;           /* polygon */
 } monchain_t;
 
+typedef LIST(monchain_t) monchains_t;
+
+/// retrieve the value of a chain entry
+///
+/// This function treats the chain as symbolically infinite, allowing out of
+/// bounds accesses to read zeroed data.
+///
+/// @param chain Chain to operate on
+/// @param index Index to lookup
+/// @return Chain value at the given index
+static monchain_t monchains_get(const monchains_t *chain, int index) {
+  assert(chain != NULL);
+
+  // infer zeroed data for out of range entries
+  if (index < 0 || (size_t)index >= LIST_SIZE(chain)) {
+    return (monchain_t){0};
+  }
+
+  return LIST_GET(chain, (size_t)index);
+}
+
+/// access the value of a chain entry for writing
+///
+/// This function treats the chain as symbolically infinite, allowing out of
+/// bounds accesses to read zeroed data.
+///
+/// @param chain Chain to operate on
+/// @param index Index to lookup
+/// @return Pointer to chain value at the given index
+static monchain_t *monchains_at(monchains_t *chain, int index) {
+  assert(chain != NULL);
+  assert(index >= 0);
+
+  // expand on demand
+  while ((size_t)index >= LIST_SIZE(chain)) {
+    LIST_APPEND(chain, (monchain_t){0});
+  }
+
+  return LIST_AT(chain, (size_t)index);
+}
+
 typedef struct {
   pointf pt;
   int vnext[4];         /* next vertices for the 4 chains */
@@ -71,10 +112,6 @@ typedef struct {
 
 static int chain_idx;
 static size_t mon_idx;
-	/* Table to hold all the monotone */
-	/* polygons . Each monotone polygon */
-	/* is a circularly linked list */
-static monchain_t* mchain;
 	/* chain init. information. This */
 	/* is used to decide which */
 	/* monotone polygon to split if */
@@ -257,8 +294,11 @@ get_vertex_positions (int v0, int v1, int *ip, int *iq)
 /* v0 and v1 are specified in anti-clockwise order with respect to 
  * the current monotone polygon mcur. Split the current polygon into 
  * two polygons using the diagonal (v0, v1) 
+ *
+ * @param chain Monotone polygon chain to operate on
  */
-static size_t make_new_monotone_poly(size_t mcur, int v0, int v1) {
+static size_t make_new_monotone_poly(monchains_t *chain, size_t mcur, int v0,
+                                     int v1) {
   int p, q, ip, iq;
   const size_t mnew = newmon();
   int i, j, nf0, nf1;
@@ -278,18 +318,18 @@ static size_t make_new_monotone_poly(size_t mcur, int v0, int v1) {
   i = new_chain_element();	/* for the new list */
   j = new_chain_element();
 
-  mchain[i].vnum = v0;
-  mchain[j].vnum = v1;
+  monchains_at(chain, i)->vnum = v0;
+  monchains_at(chain, j)->vnum = v1;
 
-  mchain[i].next = mchain[p].next;
-  mchain[mchain[p].next].prev = i;
-  mchain[i].prev = j;
-  mchain[j].next = i;
-  mchain[j].prev = mchain[q].prev;
-  mchain[mchain[q].prev].next = j;
+  monchains_at(chain, i)->next = monchains_get(chain, p).next;
+  monchains_at(chain, monchains_get(chain, p).next)->prev = i;
+  monchains_at(chain, i)->prev = j;
+  monchains_at(chain, j)->next = i;
+  monchains_at(chain, j)->prev = monchains_get(chain, q).prev;
+  monchains_at(chain, monchains_get(chain, q).prev)->next = j;
 
-  mchain[p].next = q;
-  mchain[q].prev = p;
+  monchains_at(chain, p)->next = q;
+  monchains_at(chain, q)->prev = p;
 
   nf0 = vp0->nextfree;
   nf1 = vp1->nextfree;
@@ -297,7 +337,7 @@ static size_t make_new_monotone_poly(size_t mcur, int v0, int v1) {
   vp0->vnext[ip] = v1;
 
   vp0->vpos[nf0] = i;
-  vp0->vnext[nf0] = mchain[mchain[i].next].vnum;
+  vp0->vnext[nf0] = monchains_get(chain, monchains_get(chain, i).next).vnum;
   vp1->vpos[nf1] = j;
   vp1->vnext[nf1] = v0;
 
@@ -315,10 +355,13 @@ static size_t make_new_monotone_poly(size_t mcur, int v0, int v1) {
   return mnew;
 }
 
-/* recursively visit all the trapezoids */
+/// recursively visit all the trapezoids
+///
+/// @param chain Monotone polygon chain to operate on
 static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
                              segment_t *seg, traps_t *tr, size_t mcur,
-                             size_t trnum, size_t from, int flip, int dir) {
+                             size_t trnum, size_t from, int flip, int dir,
+                             monchains_t *chain) {
   size_t mnew;
   int v0, v1;
 
@@ -362,24 +405,24 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	  v1 = t->lseg;
 	  if (from == t->d1)
 	    {
-	      mnew = make_new_monotone_poly(mcur, v1, v0);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+	      mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 	    }
 	  else
 	    {
-	      mnew = make_new_monotone_poly(mcur, v0, v1);
-	      traverse_polygon (visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-	      traverse_polygon (visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
+	      mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+	      traverse_polygon (visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+	      traverse_polygon (visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
 	    }
 	}
       else
 	{
 	  /* Just traverse all neighbours */
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
 	}
     }
   
@@ -389,24 +432,24 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	  v1 = LIST_GET(tr, t->u0).rseg;
 	  if (from == t->u1)
 	    {
-	      mnew = make_new_monotone_poly(mcur, v1, v0);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
+	      mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
 	    }
 	  else
 	    {
-	      mnew = make_new_monotone_poly(mcur, v0, v1);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
+	      mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
 	    }
 	}
       else
 	{
 	  /* Just traverse all neighbours */
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+	  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
 	}
     }
   
@@ -417,19 +460,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	  if ((dir == TR_FROM_DN && t->d1 == from) ||
 	      (dir == TR_FROM_UP && t->u1 == from))
 	    {
-	      mnew = make_new_monotone_poly(mcur, v1, v0);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+	      mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 	    }
 	  else
 	    {
-	      mnew = make_new_monotone_poly(mcur, v0, v1);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
+	      mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
 	    }
 	}
       else			/* only downward cusp */
@@ -440,19 +483,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 
 	      if (dir == TR_FROM_UP && t->u0 == from)
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
 		}
 	    }
 	  else
@@ -461,19 +504,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	      v1 = LIST_GET(tr, t->u0).rseg;	
 	      if (dir == TR_FROM_UP && t->u1 == from)
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
 		}
 	    }
 	}
@@ -485,19 +528,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	      v1 = t->lseg;
 	      if (!(dir == TR_FROM_DN && t->d0 == from))
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
 		}
 	    }
 	  else
@@ -507,19 +550,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 
 	      if (dir == TR_FROM_DN && t->d1 == from)
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
 		}
 	    }
 	}
@@ -530,19 +573,19 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 	      v1 = t->lseg;
 	      if (dir == TR_FROM_UP)
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
 		}
 	    }
 	  else if (equal_to(t->hi, seg[t->rseg].v1) &&
@@ -552,27 +595,27 @@ static void traverse_polygon(bitarray_t *visited, boxes_t *decomp,
 
 	      if (dir == TR_FROM_UP)
 		{
-		  mnew = make_new_monotone_poly(mcur, v1, v0);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP);
+		  mnew = make_new_monotone_poly(chain, mcur, v1, v0);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->d0, trnum, flip, TR_FROM_UP, chain);
 		}
 	      else
 		{
-		  mnew = make_new_monotone_poly(mcur, v0, v1);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN);
-		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN);
+		  mnew = make_new_monotone_poly(chain, mcur, v0, v1);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u0, trnum, flip, TR_FROM_DN, chain);
+		  traverse_polygon(visited, decomp, seg, tr, mnew, t->u1, trnum, flip, TR_FROM_DN, chain);
 		}
 	    }
 	  else			/* no split possible */
 	    {
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN);
-	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u0, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d0, trnum, flip, TR_FROM_UP, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->u1, trnum, flip, TR_FROM_DN, chain);
+	      traverse_polygon(visited, decomp, seg, tr, mcur, t->d1, trnum, flip, TR_FROM_UP, chain);
 	    }
 	}
     }
@@ -584,7 +627,10 @@ monotonate_trapezoids(int nsegs, segment_t *seg, traps_t *tr,
     int i;
     bitarray_t visited = bitarray_new(LIST_SIZE(tr));
 
-    mchain = gv_calloc(LIST_SIZE(tr), sizeof(monchain_t));
+    // Table to hold all the monotone polygons. Each monotone polygon is a
+    // circularly linked list
+    monchains_t mchain = {0};
+
     vert = gv_calloc(nsegs + 1, sizeof(vertexchain_t));
     mon = gv_calloc(nsegs, sizeof(int));
 
@@ -599,9 +645,9 @@ monotonate_trapezoids(int nsegs, segment_t *seg, traps_t *tr,
   /* trapezoids within the polygon */
 
     for (i = 1; i <= nsegs; i++) {
-	mchain[i].prev = seg[i].prev;
-	mchain[i].next = seg[i].next;
-	mchain[i].vnum = i;
+	monchains_at(&mchain, i)->prev = seg[i].prev;
+	monchains_at(&mchain, i)->next = seg[i].next;
+	monchains_at(&mchain, i)->vnum = i;
 	vert[i].pt = seg[i].v0;
 	vert[i].vnext[0] = seg[i].next; /* next vertex */
 	vert[i].vpos[0] = i;	/* locn. of next vertex */
@@ -616,13 +662,13 @@ monotonate_trapezoids(int nsegs, segment_t *seg, traps_t *tr,
   /* traverse the polygon */
     if (is_valid_trap(LIST_GET(tr, tr_start).u0))
 	traverse_polygon(&visited, decomp, seg, tr, 0, tr_start,
-	                 LIST_GET(tr, tr_start).u0, flip, TR_FROM_UP);
+	                 LIST_GET(tr, tr_start).u0, flip, TR_FROM_UP, &mchain);
     else if (is_valid_trap(LIST_GET(tr, tr_start).d0))
 	traverse_polygon(&visited, decomp, seg, tr, 0, tr_start,
-	                 LIST_GET(tr, tr_start).d0, flip, TR_FROM_DN);
+	                 LIST_GET(tr, tr_start).d0, flip, TR_FROM_DN, &mchain);
   
     bitarray_reset(&visited);
-    free (mchain);
+    LIST_FREE(&mchain);
     free (vert);
     free (mon);
 }
