@@ -14,6 +14,7 @@
  */
 
 #include <assert.h>
+#include <common/geomprocs.h>
 #include <common/pointset.h>
 #include <common/render.h>
 #include <math.h>
@@ -59,7 +60,7 @@ typedef struct {
  * quadratic equation a×l² + b×l + c, where a, b and
  * c are defined below.
  */
-static int computeStep(size_t ng, boxf *bbs, unsigned int margin) {
+static int computeStep(size_t ng, const boxf *bbs, unsigned int margin) {
   double l1, l2;
   double a, b, c, d, r;
   double W, H; /* width and height of graph, with margin */
@@ -415,7 +416,7 @@ static int genPoly(Agraph_t *root, Agraph_t *g, ginfo *info, int ssize,
  * If so, add cells to pointset, store point in place and return true.
  */
 static int fits(int x, int y, ginfo *info, PointSet *ps, pointf *place,
-                int step, boxf *bbs) {
+                int step, const boxf *bbs) {
   pointf *cells = info->cells;
   int n = info->nc;
   int i;
@@ -476,7 +477,7 @@ static void placeFixed(ginfo *info, PointSet *ps, pointf *place,
  * First graph (i == 0) is centered on the origin if possible.
  */
 static void placeGraph(size_t i, ginfo *info, PointSet *ps, pointf *place,
-                       int step, unsigned int margin, boxf *bbs) {
+                       int step, unsigned int margin, const boxf *bbs) {
   int x, y;
   int bnd;
   boxf bb = bbs[info->index];
@@ -598,7 +599,7 @@ static void INC(bool m, size_t *c, size_t *r, size_t nc, size_t nr) {
   }
 }
 
-static pointf *arrayRects(size_t ng, boxf *gs, pack_info *pinfo) {
+static pointf *arrayRects(size_t ng, const boxf *gs, pack_info *pinfo) {
   size_t nr = 0, nc;
   size_t r, c;
   ainfo *info;
@@ -710,7 +711,7 @@ static pointf *arrayRects(size_t ng, boxf *gs, pack_info *pinfo) {
   return places;
 }
 
-static pointf *polyRects(size_t ng, boxf *gs, pack_info *pinfo) {
+static pointf *polyRects(size_t ng, const boxf *gs, pack_info *pinfo) {
   int stepSize;
   Dict_t *ps;
 
@@ -1115,7 +1116,7 @@ int packSubgraphs(size_t ng, Agraph_t **gs, Agraph_t *root, pack_info *info) {
     for (size_t i = 0; i < ng; i++) {
       g = gs[i];
       for (j = 1; j <= GD_n_cluster(g); j++) {
-        EXPANDBB(bb, GD_bb(GD_clust(g)[j]));
+        EXPANDBB(&bb, GD_bb(GD_clust(g)[j]));
       }
     }
     GD_bb(root) = bb;
