@@ -3,23 +3,21 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
 
+#include <assert.h>
+#include <limits.h>
 #include <time.h>
 #include <string.h>
 #include <math.h>
 #include <stdbool.h>
 #include <stdlib.h>
-#include <cgraph/alloc.h>
-#include <cgraph/exit.h>
-#include <cgraph/unused.h>
 #include <common/types.h>
-#include <common/memory.h>
 #include <common/globals.h>
 
 #include <sfdpgen/sparse_solve.h>
@@ -27,7 +25,11 @@
 #include <neatogen/overlap.h>
 #include <sfdpgen/spring_electrical.h>
 #include <neatogen/call_tri.h>
-#include <sfdpgen/sfdpinternal.h>
+#include <sfdpgen/sfdp.h>
+#include <util/alloc.h>
+#include <util/exit.h>
+#include <util/gv_math.h>
+#include <util/unused.h>
 
 #define node_degree(i) (ia[(i)+1] - ia[(i)])
 
@@ -37,7 +39,6 @@ static SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, double *x){
   SparseMatrix D;
   int *ia, *ja, i, j, k, l, nz;
   double *d;
-  int *mask = NULL;
   double len, di, sum, sumd;
 
   assert(SparseMatrix_is_symmetric(A, false));
@@ -48,11 +49,11 @@ static SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, double *x){
   if (D->type != MATRIX_TYPE_REAL){
     free(D->a);
     D->type = MATRIX_TYPE_REAL;
-    D->a = N_GNEW(D->nz,double);
+    D->a = gv_calloc(D->nz, sizeof(double));
   }
   d = D->a;
 
-  mask = N_GNEW(D->m,int);
+  int *mask = gv_calloc(D->m, sizeof(int));
   for (i = 0; i < D->m; i++) mask[i] = -1;
 
   for (i = 0; i < D->m; i++){
@@ -95,7 +96,7 @@ static SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, double *x){
     }
   }
 
-
+  free(mask);
   return D;
 }
 
@@ -105,8 +106,7 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
   /* use up to dist 2 neighbor. This is used in overcoming pherical effect with ideal distance of
      2-neighbors equal graph distance etc.
    */
-  int i, j, k, l, m = A->m, *ia = A->ia, *ja = A->ja, *iw, *jw, *id, *jd;
-  int nz;
+  int j, k, l, m = A->m, *ia = A->ia, *ja = A->ja, *iw, *jw, *id, *jd;
   double *d, *w, *lambda;
   double diag_d, diag_w, dist, s = 0, stop = 0, sbot = 0;
   SparseMatrix ID;
@@ -120,17 +120,17 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
   sm->data = NULL;
   sm->scheme = SM_SCHEME_NORMAL;
   sm->tol_cg = 0.01;
-  sm->maxit_cg = (int)sqrt((double) A->m);
+  sm->maxit_cg = floor(sqrt(A->m));
 
   lambda = sm->lambda = gv_calloc(m, sizeof(double));
-  for (i = 0; i < m; i++) sm->lambda[i] = lambda0;
+  for (int i = 0; i < m; i++) sm->lambda[i] = lambda0;
   int *mask = gv_calloc(m, sizeof(int));
 
   double *avg_dist = gv_calloc(m, sizeof(double));
 
-  for (i = 0; i < m ;i++){
+  for (int i = 0; i < m ;i++){
     avg_dist[i] = 0;
-    nz = 0;
+    int nz = 0;
     for (j = ia[i]; j < ia[i+1]; j++){
       if (i == ja[j]) continue;
       avg_dist[i] += distance(x, dim, i, ja[j]);
@@ -140,11 +140,10 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
     avg_dist[i] /= nz;
   }
 
+  for (int i = 0; i < m; i++) mask[i] = -1;
 
-  for (i = 0; i < m; i++) mask[i] = -1;
-
-  nz = 0;
-  for (i = 0; i < m; i++){
+  size_t nz = 0;
+  for (int i = 0; i < m; i++){
     mask[i] = i;
     for (j = ia[i]; j < ia[i+1]; j++){
       k = ja[j];
@@ -164,12 +163,11 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
     }
   }
 
-  sm->Lw = SparseMatrix_new(m, m, nz + m, MATRIX_TYPE_REAL, FORMAT_CSR);
-  sm->Lwd = SparseMatrix_new(m, m, nz + m, MATRIX_TYPE_REAL, FORMAT_CSR);
-  if (!(sm->Lw) || !(sm->Lwd)) {
-    StressMajorizationSmoother_delete(sm);
-    return NULL;
-  }
+  sm->Lw = SparseMatrix_new(m, m, nz + (size_t)m, MATRIX_TYPE_REAL, FORMAT_CSR);
+  assert(sm->Lw != NULL);
+  sm->Lwd = SparseMatrix_new(m, m, nz + (size_t)m, MATRIX_TYPE_REAL,
+                             FORMAT_CSR);
+  assert(sm->Lwd != NULL);
 
   iw = sm->Lw->ia; jw = sm->Lw->ja;
 
@@ -180,7 +178,7 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
   iw[0] = id[0] = 0;
 
   nz = 0;
-  for (i = 0; i < m; i++){
+  for (int i = 0; i < m; i++){
     mask[i] = i+m;
     diag_d = diag_w = 0;
     for (j = ia[i]; j < ia[i+1]; j++){
@@ -276,11 +274,12 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
     d[nz] = -diag_d;
     nz++;
 
-    iw[i+1] = nz;
-    id[i+1] = nz;
+    assert(nz <= INT_MAX);
+    iw[i + 1] = (int)nz;
+    id[i + 1] = (int)nz;
   }
   s = stop/sbot;
-  for (i = 0; i < nz; i++) d[i] *= s;
+  for (size_t i = 0; i < nz; i++) d[i] *= s;
 
   sm->scaling = s;
   sm->Lw->nz = nz;
@@ -292,65 +291,67 @@ StressMajorizationSmoother StressMajorizationSmoother2_new(SparseMatrix A, int d
   return sm;
 }
 	
-StressMajorizationSmoother SparseStressMajorizationSmoother_new(SparseMatrix A, int dim, double lambda0, double *x) {
+StressMajorizationSmoother SparseStressMajorizationSmoother_new(SparseMatrix A, int dim, double *x) {
   /* solve a stress model to achieve the ideal distance among a sparse set of edges recorded in A.
      A must be a real matrix.
    */
-  StressMajorizationSmoother sm;
-  int i, j, k, m = A->m, *ia, *ja, *iw, *jw, *id, *jd;
-  int nz;
-  double *d, *w, *lambda;
-  double diag_d, diag_w, *a, dist, s = 0, stop = 0, sbot = 0;
-  double xdot = 0;
+  int m = A->m;
+  double stop = 0, sbot = 0;
 
   assert(SparseMatrix_is_symmetric(A, false) && A->type == MATRIX_TYPE_REAL);
 
   /* if x is all zero, make it random */
-  for (i = 0; i < m*dim; i++) xdot += x[i]*x[i];
-  if (xdot == 0){
-    for (i = 0; i < m*dim; i++) x[i] = 72*drand();
+  bool has_nonzero = false;
+  for (int i = 0; i < m * dim; i++) {
+    if (!is_exactly_equal(x[i], 0)) {
+	    has_nonzero = true;
+	    break;
+    }
+  }
+  if (!has_nonzero) {
+    for (int i = 0; i < m*dim; i++) x[i] = 72*drand();
   }
 
-  ia = A->ia;
-  ja = A->ja;
-  a = A->a;
+  const int *const ia = A->ia;
+  const int *const ja = A->ja;
+  const double *const a = A->a;
 
-
-  sm = MALLOC(sizeof(struct StressMajorizationSmoother_struct));
+  StressMajorizationSmoother sm = gv_alloc(sizeof(struct StressMajorizationSmoother_struct));
   sm->scaling = 1.;
   sm->data = NULL;
   sm->scheme = SM_SCHEME_NORMAL;
   sm->D = A;
   sm->tol_cg = 0.01;
-  sm->maxit_cg = (int)sqrt((double) A->m);
+  sm->maxit_cg = floor(sqrt(A->m));
 
-  lambda = sm->lambda = MALLOC(sizeof(double)*m);
-  for (i = 0; i < m; i++) sm->lambda[i] = lambda0;
+  double *const lambda = sm->lambda = gv_calloc(m, sizeof(double));
 
-  nz = A->nz;
+  size_t nz = A->nz;
 
-  sm->Lw = SparseMatrix_new(m, m, nz + m, MATRIX_TYPE_REAL, FORMAT_CSR);
-  sm->Lwd = SparseMatrix_new(m, m, nz + m, MATRIX_TYPE_REAL, FORMAT_CSR);
-  if (!(sm->Lw) || !(sm->Lwd)) {
-    StressMajorizationSmoother_delete(sm);
-    return NULL;
-  }
+  sm->Lw = SparseMatrix_new(m, m, nz + (size_t)m, MATRIX_TYPE_REAL, FORMAT_CSR);
+  assert(sm->Lw != NULL);
+  sm->Lwd = SparseMatrix_new(m, m, nz + (size_t)m, MATRIX_TYPE_REAL,
+                             FORMAT_CSR);
+  assert(sm->Lwd != NULL);
 
-  iw = sm->Lw->ia; jw = sm->Lw->ja;
-  id = sm->Lwd->ia; jd = sm->Lwd->ja;
-  w = sm->Lw->a;
-  d = sm->Lwd->a;
+  int *const iw = sm->Lw->ia;
+  int *const jw = sm->Lw->ja;
+  int *const id = sm->Lwd->ia;
+  int *const jd = sm->Lwd->ja;
+  double *const w = sm->Lw->a;
+  double *const d = sm->Lwd->a;
   iw[0] = id[0] = 0;
 
   nz = 0;
-  for (i = 0; i < m; i++){
-    diag_d = diag_w = 0;
-    for (j = ia[i]; j < ia[i+1]; j++){
-      k = ja[j];
+  for (int i = 0; i < m; i++){
+    double diag_d = 0;
+    double diag_w = 0;
+    for (int j = ia[i]; j < ia[i+1]; j++){
+      const int k = ja[j];
       if (k != i){
 
 	jw[nz] = k;
-	dist = a[j];
+	const double dist = a[j];
 	w[nz] = -1;
 	diag_w += w[nz];
 	jd[nz] = k;
@@ -372,14 +373,16 @@ StressMajorizationSmoother SparseStressMajorizationSmoother_new(SparseMatrix A,
     d[nz] = -diag_d;
     nz++;
 
-    iw[i+1] = nz;
-    id[i+1] = nz;
+    assert(nz <= INT_MAX);
+    iw[i + 1] = (int)nz;
+    id[i + 1] = (int)nz;
   }
-  s = stop/sbot;
+  const double s = stop / sbot;
   if (s == 0) {
+    StressMajorizationSmoother_delete(sm);
     return NULL;
   }
-  for (i = 0; i < nz; i++) d[i] *= s;
+  for (size_t i = 0; i < nz; i++) d[i] *= s;
 
 
   sm->scaling = s;
@@ -411,18 +414,16 @@ void SparseStressMajorizationSmoother_delete(SparseStressMajorizationSmoother sm
 }
 
 
-double SparseStressMajorizationSmoother_smooth(SparseStressMajorizationSmoother sm, int dim, double *x, int maxit_sm, double tol){
-
-  return StressMajorizationSmoother_smooth(sm, dim, x, maxit_sm, tol);
-
-
+double SparseStressMajorizationSmoother_smooth(SparseStressMajorizationSmoother sm, int dim, double *x, int maxit_sm){
+  return StressMajorizationSmoother_smooth(sm, dim, x, maxit_sm);
 }
+
 static void get_edge_label_matrix(relative_position_constraints data, int m, int dim, double *x, SparseMatrix *LL, double **rhs){
   int edge_labeling_scheme = data->edge_labeling_scheme;
   int n_constr_nodes = data->n_constr_nodes;
   int *constr_nodes = data->constr_nodes;
   SparseMatrix A_constr = data->A_constr;
-  int *ia = A_constr->ia, *ja = A_constr->ja, ii, jj, nz, l, ll, i, j;
+  int *ia = A_constr->ia, *ja = A_constr->ja, ii, jj, l, ll, i, j;
   int *irn = data->irn, *jcn = data->jcn;
   double *val = data->val, dist, kk, k;
   double *x00 = NULL;
@@ -436,29 +437,29 @@ static void get_edge_label_matrix(relative_position_constraints data, int m, int
        j  -0.5 0.25  0.25
        k  -0.5 0.25  0.25
        in general, if i has m neighbors j, k, ..., then
-       p_ii = 1
-       p_jj = 1/m^2
-       p_ij = -1/m
-       p jk = 1/m^2
-       .    i     j    k
-       i    1    -1/m  -1/m ...
-       j   -1/m  1/m^2 1/m^2 ...
-       k   -1/m  1/m^2 1/m^2 ...
+       pᵢᵢ = 1
+       pⱼⱼ = 1 ÷ m²
+       pᵢⱼ = -1 ÷ m
+       pⱼₖ = 1 ÷ m²
+       .    i       j        k
+       i    1       -1 ÷ m   -1 ÷ m ...
+       j   -1 ÷ m   1 ÷ m²   1 ÷ m² ...
+       k   -1 ÷ m   1 ÷ m²   1 ÷ m² ...
     */
     if (!irn){
       assert((!jcn) && (!val));
-      nz = 0;
+      size_t nz = 0;
       for (i = 0; i < n_constr_nodes; i++){
 	ii = constr_nodes[i];
 	k = ia[ii+1] - ia[ii];/*usually k = 2 */
-	nz += (int)((k+1)*(k+1));
+	nz += (size_t)((k + 1) * (k + 1));
 	
       }
-      irn = data->irn = MALLOC(sizeof(int)*nz);
-      jcn = data->jcn = MALLOC(sizeof(int)*nz);
-      val = data->val = MALLOC(sizeof(double)*nz);
+      irn = data->irn = gv_calloc(nz, sizeof(int));
+      jcn = data->jcn = gv_calloc(nz, sizeof(int));
+      val = data->val = gv_calloc(nz, sizeof(double));
     }
-    nz = 0;
+    size_t nz = 0;
     for (i = 0; i < n_constr_nodes; i++){
       ii = constr_nodes[i];
       jj = ja[ia[ii]]; ll = ja[ia[ii] + 1];
@@ -489,14 +490,13 @@ static void get_edge_label_matrix(relative_position_constraints data, int m, int
     */
     if (!irn){
       assert((!jcn) && (!val));
-      nz = n_constr_nodes;
-      irn = data->irn = MALLOC(sizeof(int)*nz);
-      jcn = data->jcn = MALLOC(sizeof(int)*nz);
-      val = data->val = MALLOC(sizeof(double)*nz);
+      int nz = n_constr_nodes;
+      irn = data->irn = gv_calloc(nz, sizeof(int));
+      jcn = data->jcn = gv_calloc(nz, sizeof(int));
+      val = data->val = gv_calloc(nz, sizeof(double));
     }
-    x00 = MALLOC(sizeof(double)*m*dim);
-    for (i = 0; i < m*dim; i++) x00[i] = 0;
-    nz = 0;
+    x00 = gv_calloc(m * dim, sizeof(double));
+    size_t nz = 0;
     for (i = 0; i < n_constr_nodes; i++){
       ii = constr_nodes[i];
       jj = ja[ia[ii]]; ll = ja[ia[ii] + 1];
@@ -523,7 +523,8 @@ static UNUSED double get_stress(int m, int dim, int *iw, int *jw, double *w,
                                 double *d, double *x, double scaling) {
   int i, j;
   double res = 0., dist;
-  /* we use the fact that d_ij = w_ij*graph_dist(i,j). Also, d_ij and x are scalinged by *scaling, so divide by it to get actual unscaled streee. */
+  // We use the fact that dᵢⱼ = wᵢⱼ × graph_dist(i, j). Also, dᵢⱼ and x are
+  // scaled by ×scaling, so divide by it to get actual unscaled stress.
   for (i = 0; i < m; i++){
     for (j = iw[i]; j < iw[i+1]; j++){
       if (i == jw[j]) {
@@ -537,39 +538,15 @@ static UNUSED double get_stress(int m, int dim, int *iw, int *jw, double *w,
 
 }
 
-static void uniform_stress_augment_rhs(int m, int dim, double *x, double *y, double alpha, double M){
-  int i, j, k;
-  double dist, distij;
-  for (i = 0; i < m; i++){
-    for (j = i+1; j < m; j++){
-      dist = distance_cropped(x, dim, i, j);
-      for (k = 0; k < dim; k++){
-	distij = (x[i*dim+k] - x[j*dim+k])/dist;
-	y[i*dim+k] += alpha*M*distij;
-	y[j*dim+k] += alpha*M*(-distij);
-      }
-    }
-  }
-}
-
-static double uniform_stress_solve(SparseMatrix Lw, double alpha, int dim, double *x0, double *rhs, double tol, int maxit){
-  Operator Ax;
-  Operator Precon;
-
-  Ax = Operator_uniform_stress_matmul(Lw, alpha);
-  Precon = Operator_uniform_stress_diag_precon_new(Lw, alpha);
-
-  return cg(Ax, Precon, Lw->m, dim, x0, rhs, tol, maxit);
-
-}
-
-double StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, double *x, int maxit_sm, double tol) {
+double StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, double *x, int maxit_sm) {
   SparseMatrix Lw = sm->Lw, Lwd = sm->Lwd, Lwdd = NULL;
   int i, j, k, m, *id, *jd, *iw, *jw, idiag, iter = 0;
-  double *w, *dd, *d, *y = NULL, *x0 = NULL, *x00 = NULL, diag, diff = 1, *lambda = sm->lambda, alpha = 0., M = 0.;
+  double *w, *dd, *d, *y = NULL, *x0 = NULL, *x00 = NULL, diag, diff = 1, *lambda = sm->lambda;
   SparseMatrix Lc = NULL;
   double dij, dist;
 
+  const double tol = 0.001;
+
 
   Lwdd = SparseMatrix_copy(Lwd);
   m = Lw->m;
@@ -596,51 +573,39 @@ double StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim,
   if (sm->scheme == SM_SCHEME_NORMAL_ELABEL){
     get_edge_label_matrix(sm->data, m, dim, x, &Lc, &x00);
     if (Lc) Lw = SparseMatrix_add(Lw, Lc);
-  } else if (sm->scheme == SM_SCHEME_UNIFORM_STRESS){
-    alpha = ((double*) (sm->data))[0];
-    M = ((double*) (sm->data))[1];
   }
 
   while (iter++ < maxit_sm && diff > tol){
 
-    if (sm->scheme != SM_SCHEME_STRESS_APPROX){
-      for (i = 0; i < m; i++){
-	idiag = -1;
-	diag = 0.;
-	for (j = id[i]; j < id[i+1]; j++){
-	  if (i == jd[j]) {
-	    idiag = j;
-	    continue;
-	  }
-	  
-	  dist = distance(x, dim, i, jd[j]);
-	  if (d[j] == 0){
-	    dd[j] = 0;
-	  } else {
-	    if (dist == 0){
-	      dij = d[j]/w[j];/* the ideal distance */
-	      /* perturb so points do not sit at the same place */
-	      for (k = 0; k < dim; k++) x[jd[j]*dim+k] += 0.0001*(drand()+.0001)*dij;
-	      dist = distance(x, dim, i, jd[j]);	
-	    }
-	    dd[j] = d[j]/dist;
-	    
-	  }
-	diag += dd[j];
+    for (i = 0; i < m; i++){
+      idiag = -1;
+      diag = 0.;
+      for (j = id[i]; j < id[i+1]; j++){
+	if (i == jd[j]) {
+	  idiag = j;
+	  continue;
 	}
-	assert(idiag >= 0);
-	dd[idiag] = -diag;
-      }
-      /* solve (Lw+lambda*I) x = Lwdd y + lambda x0 */
 
-      SparseMatrix_multiply_dense(Lwdd, x, &y, dim);
-    } else {
-      for (i = 0; i < m; i++){
-	for (j = 0; j < dim; j++){
-	  y[i*dim+j] = 0;/* for stress_approx scheme, the whole rhs is calculated in stress_maxent_augment_rhs */
+	dist = distance(x, dim, i, jd[j]);
+	if (d[j] == 0){
+	  dd[j] = 0;
+	} else {
+	  if (dist == 0){
+	    dij = d[j]/w[j];/* the ideal distance */
+	    /* perturb so points do not sit at the same place */
+	    for (k = 0; k < dim; k++) x[jd[j]*dim+k] += 0.0001*(drand()+.0001)*dij;
+	    dist = distance(x, dim, i, jd[j]);	
+	  }
+	  dd[j] = d[j]/dist;
 	}
+	diag += dd[j];
       }
+      assert(idiag >= 0);
+      dd[idiag] = -diag;
     }
+    /* solve (Lw+lambda*I) x = Lwdd y + lambda x0 */
+
+    SparseMatrix_multiply_dense(Lwdd, x, y, dim);
 
     if (lambda){/* is there a penalty term? */
       for (i = 0; i < m; i++){
@@ -660,10 +625,6 @@ double StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim,
       }
       break;
     }
-    case SM_SCHEME_UNIFORM_STRESS:{/* this part can be done more efficiently using octree approximation */
-      uniform_stress_augment_rhs(m, dim, x, y, alpha, M);
-      break;
-    } 
     default:
       break;
   }
@@ -674,11 +635,7 @@ double StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim,
     }
 #endif
 
-    if (sm->scheme == SM_SCHEME_UNIFORM_STRESS){
-      uniform_stress_solve(Lw, alpha, dim, x, y, sm->tol_cg, sm->maxit_cg);
-    } else {
-      SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, sm->maxit_cg);
-    }
+    SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, sm->maxit_cg);
 
 #ifdef DEBUG_PRINT
     if (Verbose) fprintf(stderr, "stress2 = %g\n",get_stress(m, dim, iw, jw, w, d, y, sm->scaling));
@@ -725,16 +682,16 @@ void StressMajorizationSmoother_delete(StressMajorizationSmoother sm){
   free(sm);
 }
 
-TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double *x, int use_triangularization) {
-  TriangleSmoother sm;
+TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double *x,
+                                      bool use_triangularization) {
   int i, j, k, m = A->m, *ia = A->ia, *ja = A->ja, *iw, *jw, jdiag, nz;
   SparseMatrix B;
-  double *avg_dist, *lambda, *d, *w, diag_d, diag_w, dist;
+  double *d, *w, diag_d, diag_w, dist;
   double s = 0, stop = 0, sbot = 0;
 
   assert(SparseMatrix_is_symmetric(A, false));
 
-  avg_dist = N_GNEW(m,double);
+  double *avg_dist = gv_calloc(m, sizeof(double));
 
   for (i = 0; i < m ;i++){
     avg_dist[i] = 0;
@@ -748,14 +705,14 @@ TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double *x, int us
     avg_dist[i] /= nz;
   }
 
-  sm = N_GNEW(1,struct TriangleSmoother_struct);
+  TriangleSmoother sm = gv_alloc(sizeof(struct TriangleSmoother_struct));
   sm->scaling = 1;
   sm->data = NULL;
   sm->scheme = SM_SCHEME_NORMAL;
   sm->tol_cg = 0.01;
-  sm->maxit_cg = (int)sqrt((double) A->m);
+  sm->maxit_cg = floor(sqrt(A->m));
 
-  lambda = sm->lambda = N_GNEW(m,double);
+  double *lambda = sm->lambda = gv_calloc(m, sizeof(double));
   
   if (m > 2){
     if (use_triangularization){
@@ -773,7 +730,7 @@ TriangleSmoother TriangleSmoother_new(SparseMatrix A, int dim, double *x, int us
 
   SparseMatrix_delete(B);
   sm->Lwd = SparseMatrix_copy(sm->Lw);
-  if (!(sm->Lw) || !(sm->Lwd)) {
+  if (!sm->Lw || !sm->Lwd) {
     TriangleSmoother_delete(sm);
     return NULL;
   }
@@ -831,20 +788,13 @@ void TriangleSmoother_delete(TriangleSmoother sm){
 }
 
 void TriangleSmoother_smooth(TriangleSmoother sm, int dim, double *x){
-
-  StressMajorizationSmoother_smooth(sm, dim, x, 50, 0.001);
+  StressMajorizationSmoother_smooth(sm, dim, x, 50);
 }
 
-
-
-
 /* ================================ spring and spring-electrical based smoother ================ */
 SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_control ctrl, double *x){
-  SpringSmoother sm;
-  int i, j, k, l, m = A->m, *ia = A->ia, *ja = A->ja, *id, *jd;
-  int *mask, nz;
+  int j, k, l, m = A->m, *ia = A->ia, *ja = A->ja, *id, *jd;
   double *d, *dd;
-  double *avg_dist;
   SparseMatrix ID = NULL;
 
   assert(SparseMatrix_is_symmetric(A, false));
@@ -852,14 +802,14 @@ SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_con
   ID = ideal_distance_matrix(A, dim, x);
   dd = ID->a;
 
-  sm = N_GNEW(1,struct SpringSmoother_struct);
-  mask = N_GNEW(m,int);
+  SpringSmoother sm = gv_alloc(sizeof(struct SpringSmoother_struct));
+  int *mask = gv_calloc(m, sizeof(int));
 
-  avg_dist = N_GNEW(m,double);
+  double *avg_dist = gv_calloc(m, sizeof(double));
 
-  for (i = 0; i < m ;i++){
+  for (int i = 0; i < m ;i++){
     avg_dist[i] = 0;
-    nz = 0;
+    int nz = 0;
     for (j = ia[i]; j < ia[i+1]; j++){
       if (i == ja[j]) continue;
       avg_dist[i] += distance(x, dim, i, ja[j]);
@@ -869,11 +819,10 @@ SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_con
     avg_dist[i] /= nz;
   }
 
+  for (int i = 0; i < m; i++) mask[i] = -1;
 
-  for (i = 0; i < m; i++) mask[i] = -1;
-
-  nz = 0;
-  for (i = 0; i < m; i++){
+  size_t nz = 0;
+  for (int i = 0; i < m; i++){
     mask[i] = i;
     for (j = ia[i]; j < ia[i+1]; j++){
       k = ja[j];
@@ -894,17 +843,14 @@ SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_con
   }
 
   sm->D = SparseMatrix_new(m, m, nz, MATRIX_TYPE_REAL, FORMAT_CSR);
-  if (!(sm->D)){
-    SpringSmoother_delete(sm);
-    return NULL;
-  }
+  assert(sm->D != NULL);
 
   id = sm->D->ia; jd = sm->D->ja;
   d = sm->D->a;
   id[0] = 0;
 
   nz = 0;
-  for (i = 0; i < m; i++){
+  for (int i = 0; i < m; i++){
     mask[i] = i+m;
     for (j = ia[i]; j < ia[i+1]; j++){
       k = ja[j];
@@ -929,15 +875,15 @@ SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_con
 	}
       }
     }
-    id[i+1] = nz;
+    assert(nz <= INT_MAX);
+    id[i + 1] = (int)nz;
   }
   sm->D->nz = nz;
-  sm->ctrl = spring_electrical_control_new();
-  *(sm->ctrl) = *ctrl;
-  sm->ctrl->random_start = FALSE;
-  sm->ctrl->multilevels = 1;
-  sm->ctrl->step /= 2;
-  sm->ctrl->maxiter = 20;
+  sm->ctrl = ctrl;
+  sm->ctrl.random_start = false;
+  sm->ctrl.multilevels = 1;
+  sm->ctrl.step /= 2;
+  sm->ctrl.maxiter = 20;
 
   free(mask);
   free(avg_dist);
@@ -950,16 +896,12 @@ SpringSmoother SpringSmoother_new(SparseMatrix A, int dim, spring_electrical_con
 void SpringSmoother_delete(SpringSmoother sm){
   if (!sm) return;
   if (sm->D) SparseMatrix_delete(sm->D);
-  if (sm->ctrl) spring_electrical_control_delete(sm->ctrl);
 }
 
-
-
-
 void SpringSmoother_smooth(SpringSmoother sm, SparseMatrix A, int dim, double *x){
   int flag = 0;
 
-  spring_electrical_spring_embedding(dim, A, sm->D, sm->ctrl, x, &flag);
+  spring_electrical_spring_embedding(dim, A, sm->D, &sm->ctrl, x, &flag);
   assert(!flag);
 
 }
@@ -975,16 +917,16 @@ void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control c
   cpu = clock();
 #endif
 
-  switch (ctrl->smoothing){
+  switch (ctrl.smoothing){
   case SMOOTHING_RNG:
   case SMOOTHING_TRIANGLE:{
     TriangleSmoother sm;
 
     if (A->m > 2) {  /* triangles need at least 3 nodes */
-      if (ctrl->smoothing == SMOOTHING_RNG){
-        sm = TriangleSmoother_new(A, dim, x, FALSE);
+      if (ctrl.smoothing == SMOOTHING_RNG){
+        sm = TriangleSmoother_new(A, dim, x, false);
       } else {
-        sm = TriangleSmoother_new(A, dim, x, TRUE);
+        sm = TriangleSmoother_new(A, dim, x, true);
       }
       TriangleSmoother_smooth(sm, dim, x);
       TriangleSmoother_delete(sm);
@@ -996,32 +938,25 @@ void post_process_smoothing(int dim, SparseMatrix A, spring_electrical_control c
   case SMOOTHING_STRESS_MAJORIZATION_AVG_DIST:
     {
       StressMajorizationSmoother sm;
-      int k, dist_scheme = IDEAL_AVG_DIST;
+      int dist_scheme = IDEAL_AVG_DIST;
 
-      if (ctrl->smoothing == SMOOTHING_STRESS_MAJORIZATION_GRAPH_DIST){
+      if (ctrl.smoothing == SMOOTHING_STRESS_MAJORIZATION_GRAPH_DIST){
 	dist_scheme = IDEAL_GRAPH_DIST;
-      } else if (ctrl->smoothing == SMOOTHING_STRESS_MAJORIZATION_AVG_DIST){
+      } else if (ctrl.smoothing == SMOOTHING_STRESS_MAJORIZATION_AVG_DIST){
 	dist_scheme = IDEAL_AVG_DIST;
-      } else if (ctrl->smoothing == SMOOTHING_STRESS_MAJORIZATION_POWER_DIST){
+      } else if (ctrl.smoothing == SMOOTHING_STRESS_MAJORIZATION_POWER_DIST){
 	dist_scheme = IDEAL_POWER_DIST;
       }
 
-      for (k = 0; k < 1; k++){
-	sm = StressMajorizationSmoother2_new(A, dim, 0.05, x, dist_scheme);
-	StressMajorizationSmoother_smooth(sm, dim, x, 50, 0.001);
-	StressMajorizationSmoother_delete(sm);
-      }
+      sm = StressMajorizationSmoother2_new(A, dim, 0.05, x, dist_scheme);
+      StressMajorizationSmoother_smooth(sm, dim, x, 50);
+      StressMajorizationSmoother_delete(sm);
       break;
     }
   case SMOOTHING_SPRING:{
-    SpringSmoother sm;
-    int k;
-
-    for (k = 0; k < 1; k++){
-      sm = SpringSmoother_new(A, dim, ctrl, x);
-      SpringSmoother_smooth(sm, A, dim, x);
-      SpringSmoother_delete(sm);
-    }
+    SpringSmoother sm = SpringSmoother_new(A, dim, ctrl, x);
+    SpringSmoother_smooth(sm, A, dim, x);
+    SpringSmoother_delete(sm);
 
     break;
   }
