@@ -17,9 +17,11 @@
 #include <sparse/color_palette.h>
 #include <sparse/colorutil.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <string.h>
 #include <util/agxbuf.h>
 #include <util/alloc.h>
+#include <util/itos.h>
 #include <util/startswith.h>
 #include <util/unreachable.h>
 
@@ -50,7 +52,7 @@ static void color_string(agxbuf *buf, int dim, double *color){
 void attach_edge_colors(Agraph_t* g, int dim, double *colors){
   /* colors is array of dim*nedges, with color for edge i at colors[dim*i, dim(i+1))
    */
-  Agsym_t* sym = agattr(g, AGEDGE, "color", 0); 
+  Agsym_t* sym = agattr_text(g, AGEDGE, "color", 0); 
   Agedge_t* e;
   Agnode_t* n;
   agxbuf buf = {0};
@@ -58,7 +60,7 @@ void attach_edge_colors(Agraph_t* g, int dim, double *colors){
   int ie = 0;
 
   if (!sym)
-    sym = agattr (g, AGEDGE, "color", "");
+    sym = agattr_text (g, AGEDGE, "color", "");
 
   for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
     row = ND_id(n);
@@ -107,8 +109,8 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
     ND_id(n) = i++;
 
   if (format == FORMAT_COORD){
-    A = SparseMatrix_new(i, i, nedges, MATRIX_TYPE_REAL, format);
-    A->nz = nedges;
+    A = SparseMatrix_new(i, i, (size_t)nedges, MATRIX_TYPE_REAL, format);
+    A->nz = (size_t)nedges;
     I = A->ia;
     J = A->ja;
     val = A->a;
@@ -118,7 +120,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
     val = gv_calloc(nedges, sizeof(double));
   }
 
-  sym = agattr(g, AGEDGE, "weight", NULL);
+  sym = agattr_text(g, AGEDGE, "weight", NULL);
   i = 0;
   for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
     row = ND_id(n);
@@ -138,7 +140,7 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
     }
   }
   
-  if (x && (psym = agattr(g, AGNODE, "pos", NULL))) {
+  if (x && (psym = agattr_text(g, AGNODE, "pos", NULL))) {
     bool has_positions = true;
     char* pval;
     if (!(*x)) {
@@ -201,7 +203,10 @@ SparseMatrix SparseMatrix_import_dot(Agraph_t *g, int dim,
     agerrorf("Error: graph %s has missing \"pos\" information", agnameof(g));
 
   size_t sz = sizeof(double);
-  if (format == FORMAT_CSR) A = SparseMatrix_from_coordinate_arrays(nedges, nnodes, nnodes, I, J, val, type, sz);
+  if (format == FORMAT_CSR) {
+    A = SparseMatrix_from_coordinate_arrays((size_t)nedges, nnodes, nnodes, I,
+                                            J, val, type, sz);
+  }
 
 done:
   if (format != FORMAT_COORD){
@@ -237,7 +242,7 @@ int Import_dot_splines(Agraph_t* g, int *ne, char ***xsplines){
   for (n = agfstnode (g); n; n = agnxtnode (g, n))
     ND_id(n) = i++;
 
-  sym = agattr(g, AGEDGE, "pos", 0); 
+  sym = agattr_text(g, AGEDGE, "pos", 0); 
   if (!sym) return 0;
  
   *xsplines = gv_calloc(nedges, sizeof(char*));
@@ -270,9 +275,9 @@ void Dot_SetClusterColor(Agraph_t* g, float *rgb_r,  float *rgb_g,  float *rgb_b
   Agnode_t* n;
   agxbuf scluster = {0};
   unsigned i;
-  Agsym_t* clust_clr_sym = agattr(g, AGNODE, "clustercolor", NULL); 
+  Agsym_t* clust_clr_sym = agattr_text(g, AGNODE, "clustercolor", NULL); 
 
-  if (!clust_clr_sym) clust_clr_sym = agattr(g, AGNODE, "clustercolor", "-1"); 
+  if (!clust_clr_sym) clust_clr_sym = agattr_text(g, AGNODE, "clustercolor", "-1"); 
   for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
     i = ND_id(n);
     if (rgb_r && rgb_g && rgb_b) {
@@ -296,7 +301,6 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
   int i, row, ic,nc, j;
   double v;
   int type = MATRIX_TYPE_REAL;
-  char scluster[100];
   float ff;
 
   int MAX_GRPS, MIN_GRPS;
@@ -360,9 +364,9 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
   int* J = gv_calloc(nedges, sizeof(int));
   double* val = gv_calloc(nedges, sizeof(double));
 
-  sym = agattr(g, AGEDGE, "weight", NULL); 
-  clust_sym = agattr(g, AGNODE, "cluster", NULL); 
-  clust_clr_sym = agattr(g, AGNODE, "clustercolor", NULL); 
+  sym = agattr_text(g, AGEDGE, "weight", NULL); 
+  clust_sym = agattr_text(g, AGNODE, "cluster", NULL); 
+  clust_clr_sym = agattr_text(g, AGNODE, "clustercolor", NULL); 
   i = 0;
   for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
     row = ND_id(n);
@@ -379,8 +383,8 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
       i++;
     }
   }
-  A = SparseMatrix_from_coordinate_arrays(nedges, nnodes, nnodes, I, J, val,
-                                          type, sizeof(double));
+  A = SparseMatrix_from_coordinate_arrays((size_t)nedges, nnodes, nnodes, I, J,
+                                          val, type, sizeof(double));
 
   /* get clustering info */
   *clusters = gv_calloc(nnodes, sizeof(int));
@@ -436,7 +440,7 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
 
   if (noclusterinfo) {
     double modularity;
-    if (!clust_sym) clust_sym = agattr(g,AGNODE,"cluster","-1");
+    if (!clust_sym) clust_sym = agattr_text(g,AGNODE,"cluster","-1");
 
     if (clustering_scheme == CLUSTERING_MQ){
       mq_clustering(A, maxcluster,
@@ -450,8 +454,7 @@ SparseMatrix Import_coord_clusters_from_dot(Agraph_t* g, int maxcluster, int dim
     for (i = 0; i < nnodes; i++) (*clusters)[i]++;/* make into 1 based */
     for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
       i = ND_id(n);
-      snprintf(scluster, sizeof(scluster), "%d", (*clusters)[i]);
-      agxset(n,clust_sym,scluster);
+      agxset(n, clust_sym, ITOS((*clusters)[i]));
     }
     MIN_GRPS = 1;
     MAX_GRPS = nc;
@@ -589,8 +592,8 @@ void attached_clustering(Agraph_t* g, int maxcluster, int clustering_scheme){
   int* J = gv_calloc(nedges, sizeof(int));
   double* val = gv_calloc(nedges, sizeof(double));
   
-  sym = agattr(g, AGEDGE, "weight", NULL);
-  clust_sym = agattr(g, AGNODE, "cluster", NULL);
+  sym = agattr_text(g, AGEDGE, "weight", NULL);
+  clust_sym = agattr_text(g, AGNODE, "cluster", NULL);
 
   i = 0;
   for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
@@ -608,13 +611,14 @@ void attached_clustering(Agraph_t* g, int maxcluster, int clustering_scheme){
       i++;
     }
   }
-  A = SparseMatrix_from_coordinate_arrays(nedges, nnodes, nnodes, I, J, val, type, sz);
+  A = SparseMatrix_from_coordinate_arrays((size_t)nedges, nnodes, nnodes, I, J,
+                                          val, type, sz);
 
   int *clusters = gv_calloc(nnodes, sizeof(int));
 
   {
     double modularity;
-    if (!clust_sym) clust_sym = agattr(g,AGNODE,"cluster","-1");
+    if (!clust_sym) clust_sym = agattr_text(g,AGNODE,"cluster","-1");
     
     if (clustering_scheme == CLUSTERING_MQ){
       mq_clustering(A, maxcluster,
@@ -628,10 +632,7 @@ void attached_clustering(Agraph_t* g, int maxcluster, int clustering_scheme){
     for (i = 0; i < nnodes; i++) (clusters)[i]++;/* make into 1 based */
     for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
       i = ND_id(n);
-      agxbuf value_buffer = {0};
-      agxbprint(&value_buffer, "%d", clusters[i]);
-      agxset(n, clust_sym, agxbuse(&value_buffer));
-      agxbfree(&value_buffer);
+      agxset(n, clust_sym, ITOS(clusters[i]));
     }
     if (Verbose){
       fprintf(stderr," no complement clustering info in dot file, using modularity clustering. Modularity = %f, ncluster=%d\n",modularity, nc);
