@@ -1,9 +1,9 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -11,10 +11,15 @@
 #pragma once
 
 #include <color.h>
+#include <common/colorprocs.h>
+#include <util/agxbuf.h>
 
-extern int colorxlate(char *str, gvcolor_t * color, color_type_t target_type);
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-void rgb2hex(float r, float g, float b, char *cstring, const char* opacity);
-  /* dimension of cstring must be >=7 */
+void rgb2hex(float r, float g, float b, agxbuf *cstring, const char *opacity);
 
-char* hue2rgb(real hue, char *color);
+#ifdef __cplusplus
+}
+#endif
