@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -15,7 +15,7 @@
 #include <math.h>
 #include <string.h>
 #include <assert.h>
-#include <cgraph/exit.h>
+#include <util/exit.h>
 /* Applications that do not use the common library can define STANDALONE
  * to get definitions/definitions that are normally provided there.
  * In particular, note that Verbose is declared but undefined.
@@ -24,37 +24,17 @@
 #include "cgraph.h"
 #include "globals.h"
 #include "arith.h"
-#include <common/memory.h>
 #endif  /* STANDALONE */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#define set_flag(a, flag) ((a)=((a)|(flag)))
-#define test_flag(a, flag) ((a)&(flag))
-#define clear_flag(a, flag) ((a) &=(~(flag)))
-
 #ifdef STANDALONE
-#define MALLOC malloc
-#define REALLOC realloc
 
-#define N_NEW(n,t)   (t*)calloc((n),sizeof(t))
 #define MAX(a,b) ((a)>(b)?(a):b)
 #define MIN(a,b) ((a)<(b)?(a):b)
 
-#ifdef TRUE
-#undef TRUE
-#endif
-#define TRUE 1
-
-#ifdef FALSE
-#undef FALSE
-#endif
-#define FALSE 0
-
-#define PI 3.14159
-
 #define POINTS(inch) 72*(inch)
 
 #ifdef GVDLL
@@ -63,20 +43,13 @@ __declspec(dllimport) extern unsigned char Verbose;
 extern unsigned char Verbose;
 #endif
 
-#else  /* STANDALONE */
-#define MALLOC gmalloc
-#define REALLOC grealloc
 #endif    /* STANDALONE */
 
 #ifdef DEBUG
 extern double _statistics[10];
 #endif
 
-
-extern int irand(int n);
 extern double drand(void);
-extern int *random_permutation(int n);/* random permutation of 0 to n-1 */
-
 
 double* vector_subtract_to(int n, double *x, double *y);/* y = x-y */
 
