@@ -25,6 +25,9 @@ static inline int fcmp(double a, double b) {
 /// maximum of two integers
 static inline int imax(int a, int b) { return a > b ? a : b; }
 
+/// maximum of two sizes
+static inline size_t zmax(size_t a, size_t b) { return a > b ? a : b; }
+
 /// minimum of two integers
 static inline int imin(int a, int b) { return a < b ? a : b; }
 
