@@ -1,4 +1,5 @@
 /**
+ * \file
  * \brief Solve an instance of the "Variable Placement with Separation
  * Constraints" problem.
  *
@@ -25,6 +26,7 @@
 #include <memory>
 #include <sstream>
 #include <fstream>
+#include <stdexcept>
 using std::ios;
 using std::ofstream;
 
@@ -36,15 +38,18 @@ using std::set;
 	#define RECTANGLE_OVERLAP_LOGGING 0
 #endif
 
-IncVPSC::IncVPSC(const unsigned n, Variable *vs[], const unsigned m, Constraint *cs[]) 
-	: VPSC(n,vs,m,cs) {
-	inactive.assign(cs,cs+m);
+IncVPSC::IncVPSC(const unsigned n, Variable *vs[], const unsigned m_,
+                 Constraint *cs_[])
+    : VPSC(n, vs, m_, cs_) {
+	inactive.assign(cs_, cs_ + m_);
 	for(Constraint *c : inactive) {
 		c->active=false;
 	}
 }
-VPSC::VPSC(const unsigned n, Variable *vs[], const unsigned m, Constraint *cs[])
-  : bs(n, vs), cs(cs), m(m) {
+
+VPSC::VPSC(const unsigned n, Variable *vs[], const unsigned m_,
+           Constraint *cs_[])
+  : bs(n, vs), cs(cs_), m(m_) {
 	if (RECTANGLE_OVERLAP_LOGGING) {
 		printBlocks();
 		assert(!constraintGraphIsCyclic(n,vs));
@@ -88,14 +93,13 @@ void VPSC::satisfy() {
 				f<<"Error: Unsatisfied constraint: "<<*cs[i]<<"\n";
 			}
 			//assert(cs[i]->slack()>-0.0000001);
-			throw "Unsatisfied constraint";
+			throw std::runtime_error("Unsatisfied constraint");
 		}
 	}
 }
 
 void VPSC::refine() {
-	bool solved=false;
-	while(!solved) {
+	for (bool solved = false; !solved;) {
 		solved=true;
 		for(Block *b : bs) {
 			b->setUpInConstraints();
@@ -121,7 +125,7 @@ void VPSC::refine() {
 	for(unsigned i=0;i<m;i++) {
 		if(cs[i]->slack()<-0.0000001) {
 			assert(cs[i]->slack()>-0.0000001);
-			throw "Unsatisfied constraint";
+			throw std::runtime_error("Unsatisfied constraint");
 		}
 	}
 }
@@ -181,7 +185,7 @@ void IncVPSC::satisfy() {
 			lb->merge(rb,v);
 		} else {
 			if(splitCtr++>10000) {
-				throw "Cycle Error!";
+				throw std::runtime_error("Cycle Error!");
 			}
 			// constraint is within block, need to split first
 			inactive.push_back(lb->splitBetween(v->left,v->right,lb,rb));
@@ -200,7 +204,7 @@ void IncVPSC::satisfy() {
 			//assert(cs[i]->slack()>-0.0000001);
 			ostringstream s;
 			s<<"Unsatisfied constraint: "<<*v;
-			throw s.str().c_str();
+			throw std::runtime_error(s.str());
 		}
 	}
 	if (RECTANGLE_OVERLAP_LOGGING) {
@@ -235,16 +239,16 @@ void IncVPSC::splitBlocks() {
 				f<<"    found split point: "<<*v<<" lm="<<v->lm<<"\n";
 			}
 			splitCnt++;
-			Block *b = v->left->block, *l=nullptr, *r=nullptr;
+			Block *b2 = v->left->block, *l=nullptr, *r=nullptr;
 			assert(v->left->block == v->right->block);
-			double pos = b->posn;
-			b->split(l,r,v);
+			double pos = b2->posn;
+			b2->split(l,r,v);
 			l->posn=r->posn=pos;
 			l->wposn = l->posn * l->weight;
 			r->wposn = r->posn * r->weight;
 			bs.insert(l);
 			bs.insert(r);
-			b->deleted=true;
+			b2->deleted=true;
 			inactive.push_back(v);
 			if (RECTANGLE_OVERLAP_LOGGING) {
 				ofstream f(LOGFILE,ios::app);
@@ -274,11 +278,10 @@ double IncVPSC::mostViolated(ConstraintList &l, Constraint* &v) {
 	for(ConstraintList::iterator i=l.begin();i!=end;i++) {
 		Constraint *c=*i;
 		double slack = c->slack();
-		if(c->equality || slack < minSlack) {
+		if (slack < minSlack) {
 			minSlack=slack;	
 			v=c;
 			deletePoint=i;
-			if(c->equality) break;
 		}
 	}
 	// Because the constraint list is not order dependent we just
@@ -286,8 +289,8 @@ double IncVPSC::mostViolated(ConstraintList &l, Constraint* &v) {
 	// downwards.  There is always at least 1 element in the
 	// vector because of search.
 	if(deletePoint != end && minSlack<-0.0000001) {
-		*deletePoint = l[l.size()-1];
-		l.resize(l.size()-1);
+		*deletePoint = l.back();
+		l.pop_back();
 	}
 	if (RECTANGLE_OVERLAP_LOGGING) {
 		ofstream f(LOGFILE,ios::app);
@@ -383,13 +386,27 @@ bool VPSC::blockGraphIsCyclic() {
 		if(i==graph.end()) {
 			//cycle found!
 			return true;
-		} else {
-			graph.erase(i);
-			for(node * v : u->out) {
-				v->in.erase(u);
-			}
+		}
+		graph.erase(i);
+		for(node *v : u->out) {
+			v->in.erase(u);
 		}
 	}
 	return false;
 }
-
+/**
+ * @dir lib/vpsc
+ * @brief library for solving the
+ *        %Variable Placement with Separation Constraints problem
+ *        for lib/neatogen
+ *
+ * This is a quadratic programming problem in which the squared differences
+ * between a placement vector and some ideal placement are minimized subject
+ * to a set of separation constraints. This is very useful in a number of layout problems.
+ *
+ * References:
+ * - https://www.adaptagrams.org/documentation/libvpsc.html
+ * - Tim Dwyer, Kim Marriott, and Peter J. Stuckey. Fast node overlap removal.
+ *   In Proceedings 13th International Symposium on Graph Drawing (GD '05),
+ *   volume 3843 of LNCS, pages 153-164. Springer, 2006.
+ */
