@@ -1,17 +1,14 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "gvplugin.h"
+#include <gvc/gvplugin.h>
 
 extern gvplugin_installed_t gvlayout_dot_layout[];
 
@@ -21,10 +18,10 @@ static gvplugin_api_t apis[] = {
 };
 
 
-#ifdef _WIN32
-#   define GVPLUGIN_DOT_LAYOUT_API __declspec(dllexport)
+#ifdef GVDLL
+#define GVPLUGIN_DOT_LAYOUT_API __declspec(dllexport)
 #else
-#   define GVPLUGIN_DOT_LAYOUT_API
+#define GVPLUGIN_DOT_LAYOUT_API
 #endif
 
 GVPLUGIN_DOT_LAYOUT_API gvplugin_library_t gvplugin_dot_layout_LTX_library = { "dot_layout", apis };
