@@ -3,7 +3,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -12,19 +12,27 @@
 #include "gdioctx_wrapper.h"
 #include "gdgen_text.h"
 #include "gd_psfontResolve.h"
+#include <assert.h>
+#include <limits.h>
+#include <math.h>
 #include <stdbool.h>
 #include <stdlib.h>
 #include <stdint.h>
 #include <string.h>
 #include <fcntl.h>
-#include <cgraph/alloc.h>
-#include <cgraph/unreachable.h>
 #include <gvc/gvplugin_render.h>
 #include <gvc/gvplugin_device.h>
 #include <gvc/gvcint.h>	/* for gvc->g for agget */
 #include <gd.h>
+#include <gdfontt.h>
+#include <gdfonts.h>
+#include <gdfontmb.h>
+#include <gdfontl.h>
+#include <gdfontg.h>
+#include <util/alloc.h>
+#include <util/unreachable.h>
 
-typedef enum {
+enum {
 	FORMAT_GIF,
 	FORMAT_JPEG,
 	FORMAT_PNG,
@@ -32,10 +40,10 @@ typedef enum {
 	FORMAT_GD,
 	FORMAT_GD2,
 	FORMAT_XBM,
-} format_type;
+};
 
 extern bool mapbool(const char *);
-extern pointf Bezier(pointf * V, int degree, double t, pointf * Left, pointf * Right);
+extern pointf Bezier(pointf *V, double t, pointf *Left, pointf *Right);
 
 #define BEZIERSUBDIVISION 10
 
@@ -92,29 +100,32 @@ static void gdgen_begin_page(GVJ_t * job)
     } else {
         if (job->width * job->height >= GD_XYMAX) {
 	    double scale = sqrt(GD_XYMAX / (job->width * job->height));
-	    job->width *= scale;
-	    job->height *= scale;
+	    assert(scale > 0 && scale <= 1);
+	    job->width = (unsigned)(job->width * scale);
+	    job->height = (unsigned)(job->height * scale);
 	    job->zoom *= scale;
 	    fprintf(stderr,
 		"%s: graph is too large for gd-renderer bitmaps. Scaling by %g to fit\n",
 		job->common->cmdname, scale);
 	}
+	assert(job->width <= INT_MAX);
+	assert(job->height <= INT_MAX);
 	if (truecolor_p) {
 	    if (job->common->verbose)
 		fprintf(stderr,
-			"%s: allocating a %dK TrueColor GD image (%d x %d pixels)\n",
+			"%s: allocating a %0.fK TrueColor GD image (%d x %d pixels)\n",
 			job->common->cmdname,
-			ROUND(job->width * job->height * 4 / 1024.),
+			round(job->width * job->height * 4 / 1024.),
 			job->width, job->height);
-	    im = gdImageCreateTrueColor(job->width, job->height);
+	    im = gdImageCreateTrueColor((int)job->width, (int)job->height);
 	} else {
 	    if (job->common->verbose)
 		fprintf(stderr,
-			"%s: allocating a %dK PaletteColor GD image (%d x %d pixels)\n",
+			"%s: allocating a %.0fK PaletteColor GD image (%d x %d pixels)\n",
 			job->common->cmdname,
-			ROUND(job->width * job->height / 1024.),
+			round(job->width * job->height / 1024.),
 			job->width, job->height);
-	    im = gdImageCreate(job->width, job->height);
+	    im = gdImageCreate((int)job->width, (int)job->height);
 	}
         job->context = im;
     }
@@ -133,16 +144,13 @@ static void gdgen_begin_page(GVJ_t * job)
 
     /* Blending must be off to lay a transparent basecolor.
        Nothing to blend with anyway. */
-    gdImageAlphaBlending(im, FALSE);
+    gdImageAlphaBlending(im, false);
     gdImageFill(im, im->sx / 2, im->sy / 2, transparent);
     /* Blend everything else together,
        especially fonts over non-transparent backgrounds */
-    gdImageAlphaBlending(im, TRUE);
+    gdImageAlphaBlending(im, true);
 }
 
-extern int gvdevice_gd_putBuf (gdIOCtx *context, const void *buffer, int len);
-extern void gvdevice_gd_putC (gdIOCtx *context, int C);
-
 static void gdgen_end_page(GVJ_t * job)
 {
     gdImagePtr im = job->context;
@@ -230,38 +238,11 @@ static void gdgen_end_page(GVJ_t * job)
     }
 }
 
-#ifdef HAVE_GD_FREETYPE
-static void gdgen_missingfont(char *fontreq) {
-    static char *lastmissing = 0;
-    static int n_errors = 0;
-
-    if (n_errors >= 20)
-	return;
-    if (lastmissing == 0 || strcmp(lastmissing, fontreq)) {
-#ifndef HAVE_GD_FONTCONFIG
-	char *p = getenv("GDFONTPATH");
-	if (!p)
-	    p = DEFAULT_FONTPATH;
-#endif
-	free(lastmissing);
-	lastmissing = gv_strdup(fontreq);
-	n_errors++;
-    }
-}
-#endif
-
 /* fontsize at which text is omitted entirely */
 #define FONTSIZE_MUCH_TOO_SMALL 0.15
 /* fontsize at which text is rendered by a simple line */
 #define FONTSIZE_TOO_SMALL 1.5
 
-#ifdef GVDLL
-#define GD_IMPORT __declspec(dllimport)
-#else
-#define GD_IMPORT
-#endif
-GD_IMPORT extern gdFontPtr gdFontTiny, gdFontSmall, gdFontMediumBold, gdFontLarge, gdFontGiant;
-
 void gdgen_text(gdImagePtr im, pointf spf, pointf epf, int fontcolor, double fontsize, int fontdpi, double fontangle, char *fontname, char *str)
 {
     gdFTStringExtra strex;
@@ -301,7 +282,6 @@ void gdgen_text(gdImagePtr im, pointf spf, pointf epf, int fontcolor, double fon
 
         if (err) {
             /* revert to builtin fonts */
-            gdgen_missingfont(fontname);
 #endif
             sp.y += 2;
             if (fontsize <= 8.5) {
@@ -379,7 +359,7 @@ static void gdgen_textspan(GVJ_t * job, pointf p, textspan_t * span)
 static int gdgen_set_penstyle(GVJ_t * job, gdImagePtr im, gdImagePtr* brush)
 {
     obj_state_t *obj = job->obj;
-    int i, pen, width, dashstyle[40];
+    int i, pen, width, dashstyle[20];
 
     if (obj->pen == PEN_DASHED) {
 	for (i = 0; i < 10; i++)
@@ -391,7 +371,7 @@ static int gdgen_set_penstyle(GVJ_t * job, gdImagePtr im, gdImagePtr* brush)
     } else if (obj->pen == PEN_DOTTED) {
 	for (i = 0; i < 2; i++)
 	    dashstyle[i] = obj->pencolor.u.index;
-	for (; i < 14; i++)
+	for (; i < 12; i++)
 	    dashstyle[i] = gdTransparent;
 	gdImageSetStyle(im, dashstyle, 12);
 	pen = gdStyled;
@@ -404,7 +384,7 @@ static int gdgen_set_penstyle(GVJ_t * job, gdImagePtr im, gdImagePtr* brush)
 	width = PENWIDTH_NORMAL;  /* gd can't do thin lines */
     gdImageSetThickness(im, width);
     /* use brush instead of Thickness to improve end butts */
-    if (width != PENWIDTH_NORMAL) {
+    if (width != (int)PENWIDTH_NORMAL) {
 	if (im->trueColor) {
 	    *brush = gdImageCreateTrueColor(width,width);
 	}
@@ -424,12 +404,11 @@ static int gdgen_set_penstyle(GVJ_t * job, gdImagePtr im, gdImagePtr* brush)
     return pen;
 }
 
-static void
-gdgen_bezier(GVJ_t *job, pointf *A, int n, int filled) {
+static void gdgen_bezier(GVJ_t *job, pointf *A, size_t n, int filled) {
     obj_state_t *obj = job->obj;
     gdImagePtr im = job->context;
     pointf p0, p1, V[4];
-    int i, j, step, pen;
+    int step, pen;
     bool pen_ok, fill_ok;
     gdImagePtr brush = NULL;
     gdPoint F[4];
@@ -445,13 +424,13 @@ gdgen_bezier(GVJ_t *job, pointf *A, int n, int filled) {
         V[3] = A[0];
         PF2P(A[0], F[0]);
         PF2P(A[n-1], F[3]);
-        for (i = 0; i + 3 < n; i += 3) {
+        for (size_t i = 0; i + 3 < n; i += 3) {
 	    V[0] = V[3];
-	    for (j = 1; j <= 3; j++)
+	    for (size_t j = 1; j <= 3; j++)
 	        V[j] = A[i + j];
 	    p0 = V[0];
 	    for (step = 1; step <= BEZIERSUBDIVISION; step++) {
-	        p1 = Bezier(V, 3, (double) step / BEZIERSUBDIVISION, NULL, NULL);
+	        p1 = Bezier(V, (double)step / BEZIERSUBDIVISION, NULL, NULL);
 	        PF2P(p0, F[1]);
 	        PF2P(p1, F[2]);
 	        if (pen_ok)
@@ -469,12 +448,10 @@ gdgen_bezier(GVJ_t *job, pointf *A, int n, int filled) {
 static gdPoint *points;
 static size_t points_allocated;
 
-static void gdgen_polygon(GVJ_t * job, pointf * A, int n, int filled)
-{
+static void gdgen_polygon(GVJ_t *job, pointf *A, size_t n, int filled) {
     obj_state_t *obj = job->obj;
     gdImagePtr im = job->context;
     gdImagePtr brush = NULL;
-    int i;
     int pen;
     bool pen_ok, fill_ok;
 
@@ -486,19 +463,20 @@ static void gdgen_polygon(GVJ_t * job, pointf * A, int n, int filled)
     fill_ok = filled && obj->fillcolor.u.index != gdImageGetTransparent(im);
 
     if (pen_ok || fill_ok) {
-        if (n > 0 && (size_t)n > points_allocated) {
-	    points = gv_recalloc(points, points_allocated, (size_t)n, sizeof(gdPoint));
-	    points_allocated = (size_t)n;
+        if (n > points_allocated) {
+	    points = gv_recalloc(points, points_allocated, n, sizeof(gdPoint));
+	    points_allocated = n;
 	}
-        for (i = 0; i < n; i++) {
+        for (size_t i = 0; i < n; i++) {
 	    points[i].x = ROUND(A[i].x);
 	    points[i].y = ROUND(A[i].y);
         }
+        assert(n <= INT_MAX);
         if (fill_ok)
-	    gdImageFilledPolygon(im, points, n, obj->fillcolor.u.index);
+	    gdImageFilledPolygon(im, points, (int)n, obj->fillcolor.u.index);
     
         if (pen_ok)
-            gdImagePolygon(im, points, n, pen);
+            gdImagePolygon(im, points, (int)n, pen);
     }
     if (brush)
 	gdImageDestroy(brush);
@@ -534,11 +512,9 @@ static void gdgen_ellipse(GVJ_t * job, pointf * A, int filled)
 	gdImageDestroy(brush);
 }
 
-static void gdgen_polyline(GVJ_t * job, pointf * A, int n)
-{
+static void gdgen_polyline(GVJ_t *job, pointf *A, size_t n) {
     gdImagePtr im = job->context;
     pointf p, p1;
-    int i;
     int pen;
     bool pen_ok;
     gdImagePtr brush = NULL;
@@ -551,7 +527,7 @@ static void gdgen_polyline(GVJ_t * job, pointf * A, int n)
 
     if (pen_ok) {
         p = A[0];
-        for (i = 1; i < n; i++) {
+        for (size_t i = 1; i < n; i++) {
 	    p1 = A[i];
 	    gdImageLine(im, ROUND(p.x), ROUND(p.y),
 		        ROUND(p1.x), ROUND(p1.y), pen);
@@ -603,14 +579,16 @@ static gvrender_features_t render_features_gd = {
     RGBA_BYTE,			/* color_type */
 };
 
-#ifdef HAVE_GD_GIF
+#if defined(HAVE_GD_GIF) || defined(HAVE_GD_JPEG)
 static gvdevice_features_t device_features_gd = {
     GVDEVICE_BINARY_FORMAT,	/* flags */
     {0.,0.},			/* default margin - points */
     {0.,0.},                    /* default page width, height - points */
     {96.,96.},			/* default dpi */
 };
+#endif
 
+#if defined(HAVE_GD_GIF) || defined(HAVE_GD_PNG)
 static gvdevice_features_t device_features_gd_tc = {
     GVDEVICE_BINARY_FORMAT
       | GVDEVICE_DOES_TRUECOLOR,/* flags */
