@@ -1,9 +1,9 @@
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -25,5 +25,5 @@ static gvplugin_api_t apis[] = {
 #define GVPLUGIN_NEATO_LAYOUT_API
 #endif
 
-GVPLUGIN_NEATO_LAYOUT_API gvplugin_library_t gvplugin_neato_layout_LTX_library = { "neato_layout", apis };
-
+GVPLUGIN_NEATO_LAYOUT_API gvplugin_library_t
+    gvplugin_neato_layout_LTX_library = {"neato_layout", apis};
