@@ -3,13 +3,12 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef _GVGETFONTLIST_H
-#define _GVGETFONTLIST_H
+#pragma once
 
 #include <pango/pangocairo.h>
 
@@ -27,5 +26,3 @@ extern gv_font_map* get_font_mapping(PangoFontMap * pfm);
 #ifdef __cplusplus
 }
 #endif
-
-#endif  /* _GVGETFONTLIST_H */
