@@ -14,22 +14,17 @@
 
 #include "gvplugin_quartz.h"
 #include <stdbool.h>
-#include <TargetConditionals.h>
 #include <util/gv_math.h>
 
-#if !TARGET_OS_IPHONE && defined(HAVE_PANGOCAIRO)
+#if __ENVIRONMENT_MAC_OS_X_VERSION_MIN_REQUIRED__ >= 1040 && defined(HAVE_PANGOCAIRO)
 
 static const void *memory_data_consumer_get_byte_pointer(void *info)
 {
 	return info;
 }
 
-CGDataProviderDirectCallbacks memory_data_provider_callbacks = {
-	0,
-	memory_data_consumer_get_byte_pointer,
-	NULL,
-	NULL,
-	NULL
+static CGDataProviderDirectCallbacks memory_data_provider_callbacks = {
+    .getBytePointer = memory_data_consumer_get_byte_pointer,
 };
 
 static void quartz_format(GVJ_t *job)
