@@ -334,6 +334,32 @@ def is_static_build() -> bool:
     return False
 
 
+def is_ubuntu() -> bool:
+    """is the current environment Ubuntu?"""
+    return freedesktop_os_release().get("ID") == "ubuntu"
+
+
+def is_ubuntu_2404() -> bool:
+    """is the current environment Ubuntu 24.04?"""
+    if not is_ubuntu():
+        return False
+    return freedesktop_os_release().get("VERSION_ID") == "24.04"
+
+
+def is_ubuntu_2504() -> bool:
+    """is the current environment Ubuntu 25.04?"""
+    if not is_ubuntu():
+        return False
+    return freedesktop_os_release().get("VERSION_ID") == "25.04"
+
+
+def is_ubuntu_2510() -> bool:
+    """is the current environment Ubuntu 25.10?"""
+    if not is_ubuntu():
+        return False
+    return freedesktop_os_release().get("VERSION_ID") == "25.10"
+
+
 def remove_asan_summary(s: str) -> str:
     """
     Remove the “Suppressions used…” informational text Address Sanitizer prints.
