@@ -1,14 +1,13 @@
 #pragma once
 
 #include <cmath>
+#include <format>
 #include <optional>
 #include <stdexcept>
 #include <string>
 #include <string_view>
 #include <vector>
 
-#include <fmt/format.h>
-
 namespace SVG {
 
 struct SVGPoint {
@@ -22,6 +21,8 @@ struct SVGPoint {
   bool is_more_right_than(const SVGPoint &other) const;
 };
 
+using SVGPoints = std::vector<SVGPoint>;
+
 struct SVGLine {
   double x1;
   double y1;
@@ -63,7 +64,7 @@ enum class SVGElementType {
   Title,
 };
 
-std::string_view tag(SVG::SVGElementType type);
+std::string_view tag(SVG::SVGElementType elem_type);
 
 struct SVGAttributes {
   std::string class_;
@@ -75,7 +76,7 @@ struct SVGAttributes {
   double font_size;
   double height;
   std::string id;
-  std::vector<SVGPoint> points;
+  SVGPoints points;
   double rx;
   double ry;
   std::string stroke;
@@ -98,7 +99,7 @@ std::string to_dot_color(const std::string &color, double opacity = 1.0);
 class SVGElement {
 public:
   SVGElement() = delete;
-  explicit SVGElement(SVG::SVGElementType type);
+  explicit SVGElement(SVG::SVGElementType etype);
 
   /// Add an SVG `rect` element representing the bounding box of the edge to the
   /// element
@@ -144,9 +145,10 @@ public:
         continue;
       }
       if (attribute.value() != child_attribute) {
-        throw std::runtime_error{fmt::format(
+        throw std::runtime_error{std::format(
             "Inconsistent value of attribute: current {}: {}, child {}: {}",
-            tag(type), attribute.value(), tag(child.type), child_attribute)};
+            tag(elem_type), attribute.value(), tag(child.elem_type),
+            child_attribute)};
       }
     }
     return attribute.value_or(default_value);
@@ -161,7 +163,7 @@ public:
   /// Return the element of the given type with the specified index found among
   /// the element's children. Throwns an exception if there's no such element
   /// with the specified index.
-  SVG::SVGElement &find_child(SVG::SVGElementType type, std::size_t index = 0);
+  SVG::SVGElement &find_child(SVG::SVGElementType etype, std::size_t index = 0);
   bool is_closed_shape_element() const;
   bool is_shape_element() const;
   /// Return the outline bounding box of the element. The outline bounding box
@@ -183,12 +185,12 @@ public:
   /// The Graphviz release version
   std::string graphviz_version;
   /// The points given by the `d` attribute of a path element
-  std::vector<SVGPoint> path_points;
+  SVGPoints path_points;
   /// The SVG element text node contents. Not to be confused with an SVG `text`
   /// element
   std::string text;
   /// The type of SVG element
-  const SVGElementType type;
+  const SVGElementType elem_type;
 
 private:
   /// append a string possibly containing an attribute to another string,
@@ -205,9 +207,9 @@ private:
   std::string fill_opacity_attribute_to_string() const;
   /// Compute the stroke shape miter point according to
   /// https://www.w3.org/TR/SVG2/painting.html#StrokeShape.
-  SVG::SVGPoint miter_point(SVG::SVGPoint segment_start,
-                            SVG::SVGPoint segment_end,
-                            SVG::SVGPoint following_segment_end) const;
+  SVG::SVGPoints miter_shape(SVG::SVGPoint segment_start,
+                             SVG::SVGPoint segment_end,
+                             SVG::SVGPoint following_segment_end) const;
   std::string points_attribute_to_string() const;
   std::string stroke_attribute_to_string() const;
   std::string stroke_opacity_attribute_to_string() const;
