@@ -1,14 +1,15 @@
+#include <format>
 #include <iostream>
 #include <string>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "test_edge_node_overlap_utilities.h"
 #include "test_utilities.h"
 
 TEST_CASE("Overlap point node shape",
-          "[!shouldfail] Test that an edge connected to a 'point' shaped node "
-          "touches that node and does not overlap it too much") {
+          "Test that an edge connected to a 'point' shaped node touches that "
+          "node and does not overlap it too much") {
 
   const auto shape = "point";
   INFO("Node shape: " << shape);
@@ -23,7 +24,7 @@ TEST_CASE("Overlap point node shape",
       .edge_penwidth = 2,
   };
 
-  const auto filename_base = fmt::format("{}_rankdir_{}", AUTO_NAME(), rankdir);
+  const auto filename_base = std::format("{}_rankdir_{}", AUTO_NAME(), rankdir);
 
   test_edge_node_overlap(graph_options, {}, {.filename_base = filename_base});
 }
