@@ -1,5 +1,5 @@
-#include <catch2/catch.hpp>
-#include <fmt/format.h>
+#include <catch2/catch_all.hpp>
+#include <format>
 
 #include "svg_analyzer.h"
 #include "test_utilities.h"
@@ -10,13 +10,13 @@ TEST_CASE("Edge penwidth",
 
   const auto primitive_arrow_shape =
       GENERATE(from_range(all_primitive_arrow_shapes));
-  INFO(fmt::format("Primitive arrow shape: {}", primitive_arrow_shape));
+  INFO("Primitive arrow shape: " << primitive_arrow_shape);
 
   const auto edge_penwidth = GENERATE(0.5, 1.0, 2.0);
-  INFO(fmt::format("Edge penwidth: {}", edge_penwidth));
+  INFO("Edge penwidth: " << edge_penwidth);
 
   auto dot =
-      fmt::format("digraph g1 {{edge [arrowhead={} penwidth={}]; a -> b}}",
+      std::format("digraph g1 {{edge [arrowhead={} penwidth={}]; a -> b}}",
                   primitive_arrow_shape, edge_penwidth);
 
   const auto engine = "dot";
