@@ -1,12 +1,12 @@
 #include <string>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "test_edge_node_overlap_utilities.h"
 #include "test_utilities.h"
 
 TEST_CASE("Minimum edge stem and arrow overlap",
-          "An edge stem shall touch it's arrow heads") {
+          "Test that an edge stem touches its arrow heads") {
 
   const graph_options graph_options = {
       .node_shape = "polygon",
