@@ -1,3 +1,7 @@
+#include <filesystem>
+#include <format>
+#include <fstream>
+#include <stdexcept>
 #include <string_view>
 #include <unordered_set>
 
@@ -174,6 +178,10 @@ bool contains_multiple_shapes_with_different_fill(
          contains_polyline_shape(shape);
 }
 
+bool is_polygon_shape(const std::string_view shape) {
+  return node_shapes_consisting_of_polygon.contains(shape);
+}
+
 const std::unordered_set<std::string_view> primitive_polygon_arrow_shapes = {
     "crow", "diamond", "inv", "normal", "vee"};
 
@@ -188,5 +196,24 @@ const std::unordered_set<std::string_view>
     primitive_arrow_shapes_without_closed_svg_shape = {"curve", "icurve",
                                                        "none"};
 
+const std::unordered_set<std::string_view> all_arrow_shape_modifiers = {
+    "", "o", "l", "r"};
+
 const std::unordered_set<std::string_view> all_rank_directions = {"TB", "BT",
                                                                   "LR", "RL"};
+
+const std::unordered_set<std::string_view> all_edge_directions = {
+    "forward", "back", "both", "none"};
+
+void write_to_file(const std::filesystem::path &directory,
+                   const std::filesystem::path &filename,
+                   const std::string_view text) {
+  std::filesystem::create_directories(directory);
+  const std::filesystem::path test_artifacts_path = directory / filename;
+  std::ofstream outfile{test_artifacts_path};
+  if (!outfile.is_open()) {
+    throw std::runtime_error{std::format("Could not create output file \"{}\"",
+                                         test_artifacts_path.native())};
+  }
+  outfile << text;
+}
